@@ -1,7 +1,9 @@
 <?php
+$lang['invalidemail'] = 'Die eingegebene Email-Adresse ist ung&uuml;ltig';
+$lang['empty_query'] = 'Leere Abfrage?? %s';
 $lang['no_db_driver'] = 'Keine kompatiblen Datenbanktreiber gefunden';
-$lang['test_check_output_buffering'] = 'Pr&uuml;fung auf output buffering';
-$lang['test_check_output_buffering_failed'] = 'Output buffering ist bei Ihrem Host deaktiviert. Sie k&ouml;nnen daher keine der Funktionalit&auml;ten verwenden, die diese Funktion ben&ouml;tigen.';
+$lang['test_check_output_buffering'] = 'Pr&uuml;fung auf die Funktion output buffering';
+$lang['test_check_output_buffering_failed'] = 'Die Funktion Output buffering ist bei Ihrem Host deaktiviert. Sie k&ouml;nnen daher keine der Funktionalit&auml;ten verwenden, die diese Funktion ben&ouml;tigen.';
 $lang['phpinfo'] = 'Anzeige der PHP-Informationen';
 $lang['mod_security'] = 'Apache-Security-Modul';
 $lang['test_check_tempnam'] = 'Pr&uuml;fung auf die Funktion tempnam';
@@ -83,7 +85,7 @@ $lang['install_warn_db_createtables'] = 'Normalerweise sollte dieses Feld regelm
 $lang['install_admin_tablesnotcreated'] = 'Die Installation ist jetzt vollst&auml;ndig. Aufgrund Ihrer Einstellungen wurden die Datenbanktabellen NICHT erzeugt. Die Einstellungen wurden in der Datei config.php wurden gespeichert und alle Tests erfolgreich absolviert.  Vielen Dank, hier ist Ihr';
 $lang['info_create_dir_and_file'] = 'Der httpd-Proze&szlig; konnte keine Datei in eigenen Verzeichnissen erzeugen. Das bedeutet, dass der Safe-Modus auf Ihrem Host aktiviert ist. Ohne diese F&auml;higkeit k&ouml;nnen einige Funktionen von CMS made simple jedoch nicht arbeiten. Die Fortsetzung ist daher nicht m&ouml;glich.';
 $lang['test_create_dir_and_file'] = 'Pr&uuml;fung, ob der httpd-Proze&szlig; eine Datei in einem selbst erstellten Verzeichnis erzeugen kann.';
-$lang['cms_site'] = 'CMS Seite';
+$lang['cms_site'] = 'CMS-Seite';
 $lang['or_greater'] = 'Oder h&ouml;her';
 $lang['sitename'] = 'Name der Webseite';
 $lang['warning_safe_mode'] = '<strong><em>WARNUNG:</em></strong> Der PHP-Safe-Modus ist auf Ihrem Server aktiviert. Beim Hochladen von Bildern, Themes und Modul-XML-Dateien kann es zu Problemen kommen. Fragen Sie den Server-Administrator, ob er den Safe-Modus deaktiviert.';
@@ -143,7 +145,7 @@ $lang['cantchmodfiles'] = 'Die Berechtigungen einiger Dateien konnten nicht ge&a
 $lang['cantremovefiles'] = 'Problem beim Entfernen von Dateien (Berechtigungen?)';
 $lang['create'] = 'Erstellen';
 $lang['database'] = 'Datenbank';
-$lang['databaseprefix'] = 'Datenbank-Prefix';
+$lang['databaseprefix'] = 'Datenbank-Pr&auml;fix (aus Sicherheitsgr&uuml;nden sollten Sie die Buchstaben &auml;ndern)';
 $lang['databasetype'] = 'Datenbank-Typ';
 $lang['date'] = 'Datum';
 $lang['default'] = 'Standard';
@@ -157,7 +159,7 @@ $lang['email'] = 'Email-Adresse';
 $lang['errordeletingfile'] = 'Die Datei konnte nicht gel&ouml;scht werden. Ein Berechtigungsproblem?';
 $lang['errordirectorynotwritable'] = 'Fehlende Berechtigung, in dieses Verzeichnis zu schreiben. Ursache daf&uuml;r k&ouml;nnen die gesetzten Berechtigungen und die Eigent&uuml;merschaft sein. Au&szlig;erdem kann dies eine Auswirkung des Safe-Modus sein.';
 $lang['cachenotwritable'] = 'Das cache-Verzeichnis ist nicht beschreibbar. Der Zwischenspeicher kann daher nicht geleert werden. Bitte geben Sie dem Verzeichnis tmp/cache die vollen Lese-/Schreib- und Ausf&uuml;hrungsberechtigungen (chmod 777). Zus&auml;tzlich sollten Sie den Safe-Modus deaktivieren.';
-$lang['modulesnotwritable'] = 'Das /modules-Verzeichnis ist nicht beschreibbar. Wenn Sie Module &uuml;ber die Administration installieren m&ouml;chten (als XML-Datei), sollten Sie diesem Verzeichnis die vollen Lese-/Schreib- und Ausf&uuml;hrungsberechtigungen geben (chmod 777). Dies kann jedoch auch eine Auswirkung des Safe-Modus sein.';
+$lang['modulesnotwritable'] = 'Das modules-Verzeichnis ist nicht beschreibbar. Wenn Sie Module &uuml;ber die Administration installieren m&ouml;chten (als XML-Datei), sollten Sie diesem Verzeichnis die vollen Lese-/Schreib- und Ausf&uuml;hrungsberechtigungen geben (chmod 777). Dies kann jedoch auch eine Auswirkung des Safe-Modus sein.';
 $lang['false'] = 'Falsch';
 $lang['settrue'] = 'Auf True setzen';
 $lang['filename'] = 'Dateiname';
@@ -187,7 +189,7 @@ $lang['install_thanks'] = 'Vielen Dank f&uuml;r die Installation von CMS made si
 $lang['upgrade_title'] = 'CMS made simple - Aktualisierung - Schritt %s';
 $lang['upgrade_system'] = 'Aktualisierungs-System';
 $lang['upgrade_thanks'] = 'Vielen Dank f&uuml;r die Aktualisierung von CMS made simple auf ';
-$lang['install_please_read'] = 'Sollten bei der Installation Probleme auftreten, lesen Sie bitte den Abschnitt <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/de">Fehlersuche</a> im CMS made simple Wiki.';
+$lang['install_please_read'] = 'Sollten bei der Installation Probleme auftreten, lesen Sie bitte den Abschnitt <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/de">Fehlersuche</a> im CMS made simple Wiki.';
 $lang['install_checking'] = 'Berechtigungen und PHP-Einstellungen pr&uuml;fen';
 $lang['install_test'] = 'Testen';
 $lang['install_result'] = 'Ergebnis';
@@ -196,15 +198,15 @@ $lang['install_recommended_settings'] = 'Empfohlene Einstellungen';
 $lang['install_you_have'] = 'Ihre Einstellung';
 $lang['install_legend'] = 'Legende';
 $lang['install_symbol'] = 'Symbol';
-$lang['install_definition'] = 'Definition';
-$lang['install_value_passed'] = 'Ein erforderlicher Test ist bestanden';
-$lang['install_value_failed'] = 'Ein erforderlicher Test ist fehlgeschlagen';
+$lang['install_definition'] = 'Erkl&auml;rung';
+$lang['install_value_passed'] = 'Dieser Test wurde bestanden';
+$lang['install_value_failed'] = 'Dieser Test wurde nicht bestanden';
 $lang['install_error_fragment'] = 'Info zur Installations-Fehlersuche';
 $lang['install_value_required'] = 'Eine Einstellung ist unterhalb des erforderlichen Minimums';
-$lang['install_value_recommended'] = 'Eine Einstellung ist oberhalb des erforderlichen, aber unterhalb des empfohlenen Wertes. <br />Es <em>kann</em> daher sein, dass bestimmte Funktionen, die f&uuml;r zus&auml;tzliche Funktionalit&auml;ten ben&ouml;tigt werden, nicht verf&uuml;gbar sind.';
+$lang['install_value_recommended'] = 'Diese Einstellung ist oberhalb des erforderlichen, aber unterhalb des empfohlenen Wertes.<br />Es <em>kann</em> daher sein, dass bestimmte Funktionen, die die empfohlene Einstellung ben&ouml;tigen, nicht genutzt werden k&ouml;nnen.';
 $lang['install_value_exceed'] = 'Eine Einstellung entspricht oder &uuml;bertrifft den empfohlenen Wert<br />Es <em>kann</em> daher sein, dass bestimmte Funktionen, die f&uuml;r zus&auml;tzliche Funktionalit&auml;ten ben&ouml;tigt werden, verf&uuml;gbar sind.';
-$lang['install_test_failed'] = 'Ein oder mehrere Tests sind fehlgeschlagen. Sie k&ouml;nnen das System zwar installieren, aber einige Funktionen werden nicht richtig funktionieren.<br />Versuchen Sie, dies zu &auml;ndern und klicken dann auf &quot;Neuer Versuch&quot;. Anderenfalls klicken Sie auf den Button &quot;Weiter&quot;.';
-$lang['install_test_passed'] = 'Alle Tests wurden bestanden (teilweise auf minimalem Niveau). Bitte klicken Sie auf &quot;Weiter&quot;.';
+$lang['install_test_failed'] = 'Ein oder mehrere Tests konnten nicht erfolgreich abgeschlossen werden. Sie k&ouml;nnen das System installieren, aber m&ouml;glicherweise stehen einige Funktionen nicht zur Verf&uuml;gung.<br />Versuchen Sie, die Einstellungen Ihres Servers bzw. Host-Accounts zu &auml;ndern und klicken dann auf &quot;Neuer Versuch&quot;. Anderenfalls klicken Sie auf den Button &quot;Weiter&quot;. ';
+$lang['install_test_passed'] = 'Alle Tests wurden bestanden (teilweise mit Abstrichen). Bitte klicken Sie auf &quot;Weiter&quot;.';
 $lang['install_failed_again'] = 'Ein oder mehrere Tests sind fehlgeschlagen. Bitte beheben Sie das Problem und klicken auf &quot;Neuer Versuch&quot;, um die Tests zu wiederholen.';
 $lang['install_try_again'] = 'Neuer Versuch';
 $lang['install_continue'] = 'Weiter';
@@ -212,11 +214,11 @@ $lang['failure'] = 'Fehlgeschlagen';
 $lang['caution'] = 'Achtung';
 $lang['install_admin_umask'] = 'Maske zum Erstellen von Dateien (umask) testen';
 $lang['install_test_umask'] = 'F&uuml;r einen Test klicken Sie auf den Button &quot;Testen&quot;.';
-$lang['test_umask_text'] = 'umask (abgek&uuml;rzt f&uuml;r &quot;user file creation mode mask&quot;) ist eine Funktion in POSIX-Umgebungen, mit der die Voreinstellungen f&uuml;r neu erstellte Dateien und Verzeichnisse gesteuert werden k&ouml;nnen. Damit wird kontrolliert, welche der Berechtigungen f&uuml;r eine neu erstellte Datei nicht gesetzt werden sollen.';
+$lang['test_umask_text'] = 'umask (abgek&uuml;rzt f&uuml;r &quot;user file creation mode mask&quot;) ist eine Funktion in POSIX-Umgebungen, mit der bestimmte Voreinstellungen f&uuml;r neu erstellte Dateien und Verzeichnisse gesetzt werden k&ouml;nnen. Damit wird gesteuert, welche der Berechtigungen f&uuml;r eine neu erstellte Datei nicht gesetzt werden sollen (z.Bsp. umask 002 = chmod 775).';
 $lang['test_check_umask'] = 'Das Testergebnis wurde in einer Datei gespeichert - im Verzeichnis ';
 $lang['test_umask_not_given'] = 'Kein umask-Wert vorgegeben';
 $lang['test_check_umask_failed'] = 'Der umask-Test ist fehlgeschlagen';
-$lang['test_username_not_given'] = 'Es wurde kein Benutzername eingegeben!';
+$lang['test_username_not_given'] = 'Sie m&uuml;ssen einen Benutzernamen eingegeben!';
 $lang['test_username_illegal'] = 'Der Benutzername enth&auml;lt unzul&auml;ssige Zeichen!';
 $lang['test_not_both_passwd'] = 'Es wurden nicht beide Passwort-Felder ausgef&uuml;llt!';
 $lang['test_passwd_not_match'] = 'Die eingegebenen Passw&ouml;rter stimmen nicht &uuml;berein!';
@@ -257,7 +259,7 @@ $lang['test_check_file_upload'] = 'Pr&uuml;fung der M&ouml;glichkeit zum Hochlad
 $lang['test_check_file_failed'] = 'Wenn diese Funktion deaktiviert ist, k&ouml;nnen Sie die in CMS made simple enthaltenen F&auml;higkeiten zum Hochladen von Dateien nicht nutzen. Falls m&ouml;glich sollte Ihr Systemadministrator diese Beschr&auml;nkung aufheben. Sie sollten jedoch wissen, was Sie tun.';
 $lang['test_check_memory'] = 'Pr&uuml;fung des PHP-Speicher-Limits';
 $lang['test_check_memory_failed'] = 'M&ouml;glicherweise wird CMSms mit dem Ihnen zur Verf&uuml;gung stehenden Speicher nicht richtig funktionieren. Falls m&ouml;glich sollten Sie Ihren Systemadministrator bitten, diesen Wert zu erh&ouml;hen. Sie sollten jedoch wissen, was Sie tun.';
-$lang['test_check_time_limit'] = 'Pr&uuml;fung des PHP-Zeitlimits';
+$lang['test_check_time_limit'] = 'Pr&uuml;fung des PHP-Zeitlimits (Sekunden)';
 $lang['test_check_time_limit_failed'] = 'Zeitdauer in Sekunden, die ein PHP-Skript ben&ouml;tigen darf. Bei &Uuml;berschreitung dieses Wertes wird eine Fehlermeldung ausgegeben.';
 $lang['test_check_post_max'] = 'Pr&uuml;fung der maximalen Gr&ouml;&szlig;e f&uuml;r POST-Dateien';
 $lang['test_check_post_max_failed'] = 'Es ist Ihnen nicht m&ouml;glich, (gr&ouml;&szlig;ere) Dateien via POST zu senden. Seien Sie sich dieser Einschr&auml;nkung bewusst.';
@@ -265,7 +267,7 @@ $lang['test_check_upload_max'] = 'Pr&uuml;fung der maximal hochladbaren Datei-Gr
 $lang['test_check_upload_max_failed'] = 'Es ist Ihnen nicht m&ouml;glich, (gr&ouml;&szlig;ere) Dateien &uuml;ber die integrierte Dateiverwaltung hochzuladen. Seien Sie sich dieser Einschr&auml;nkung bewusst.';
 $lang['test_check_writable'] = 'Pr&uuml;fung, ob %s beschreibbar ist';
 $lang['test_check_upload_failed'] = 'Das uploads-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen.';
-$lang['test_check_images_failed'] = 'Das /images-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen und zu verwenden.';
+$lang['test_check_images_failed'] = 'Das Bilder-Verzeichnis (Standard: uploads/images) ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Dateien &uuml;ber die Administration hochzuladen und zu verwenden.';
 $lang['test_check_modules_failed'] = 'Das modules-Verzeichnis ist nicht beschreibbar. Sie k&ouml;nnen zwar das System installieren. Es ist dann jedoch nicht m&ouml;glich, Module &uuml;ber die Administration zu hochzuladen.';
 $lang['test_check_file_get_contents'] = 'Pr&uuml;fung auf die Funktion file_get_contents';
 $lang['test_check_file_get_contents_failed'] = 'Ihnen ist es nicht m&ouml;glich, irgend eine Funktionalit&auml;t zu verwenden, die diese Funktion ben&ouml;tigt.';
@@ -277,8 +279,8 @@ $lang['test_check_ini_set_failed'] = 'Die M&ouml;glichkeit, Einstellungen der ph
 $lang['install_admin_header'] = 'Informationen zum Administratoren-Konto';
 $lang['install_admin_info'] = 'Geben Sie hier den Benutzernamen, die Emailadresse und das Passwort f&uuml;r den Administrator ein und notieren sich diese Daten irgendwo, da Sie ohne diese Daten keinen Zugang zur Administration von CMS made simple erhalten.';
 $lang['install_admin_email'] = 'Email-Adresse';
-$lang['install_admin_email_info'] = 'Informationen zum Email-Konto';
-$lang['install_admin_email_note'] = '<strong>Hinweis:</strong> F&uuml;r diese Funktion wird die PHP-Funktion mail() verwendet. Wenn Sie diese Email nicht erhalten, kann das ein Hinweis darauf sein, dass Ihr Server nicht richtig konfiguriert ist. Sie sollten daher Ihren Hoster kontaktieren.';
+$lang['install_admin_email_info'] = 'Konto-Daten per Email versenden';
+$lang['install_admin_email_note'] = '<strong>Hinweis:</strong> F&uuml;r den Emailversand wird die PHP-Funktion mail() verwendet. Wenn Sie diese Email nicht erhalten, kann das ein Hinweis darauf sein, dass Ihr Server nicht richtig konfiguriert ist. Kontaktieren Sie daf&uuml;r Ihren Hoster.';
 $lang['install_admin_sitename'] = 'Das ist der Name Ihrer Seite. Er wird an verschiedenen Stellen der Muster-Templates verwendet und kann mit dem Tag {sitename} an beliebiger Stelle aufgerufen werden.';
 $lang['install_admin_db'] = 'Informationen zur Datenbank';
 $lang['install_admin_db_info'] = '<p>Stellen Sie sicher, dass die Datenbank erstellt und einem User alle Rechte zur Nutzung dieser Datenbank gew&auml;hrt wurden.</p>
@@ -298,7 +300,7 @@ $lang['install_admin_db_prefix'] = 'Tabellen-Prefix';
 $lang['install_admin_db_sample'] = 'Musterdaten (Templates, Inhalte) installieren';
 $lang['retry'] = 'Wiederholen';
 $lang['install_admin_db_create_seq'] = 'Erstelle die sequentielle Tabelle %s ...';
-$lang['install_admin_importing'] = 'Importiere die Musterdaten ...';
+$lang['install_admin_importing'] = 'Importiere die Beispieldaten ...';
 $lang['invalid_query'] = 'Ung&uuml;ltige Abfrage: %s';
 $lang['install_creating_table'] = '<p>Erstelle die Tabelle %s ... [%s]</p>';
 $lang['install_creating_index'] = '<p>Erzeuge Index in der Tabelle %s ... [%s]</p>';
@@ -320,7 +322,7 @@ $lang['install_admin_index_search'] = 'Erstellung des Suche-Index ... ';
 $lang['install_admin_clear_cache'] = 'L&ouml;schen des Seitencaches (falls vorhanden) ... ';
 $lang['install_admin_emailing'] = 'Die Daten f&uuml;r den Administratorzugang werden jetzt per Email versandt ... ';
 $lang['install_admin_congratulations'] = 'Gratulation, die Installation ist vollst&auml;ndig. Hier ist Ihre ';
-$lang['could_not_connect_db'] = 'Die Verbindung zur Datenbank konnte nicht hergestellt werden. Pr&uuml;fen Sie, ob der Benutzername und das Passwort richtig sind und ob der Benutzer Zugriff auf die angegebene Datenbank hat.';
+$lang['could_not_connect_db'] = 'Die Verbindung zur Datenbank konnte nicht hergestellt werden. Pr&uuml;fen Sie, ob der Benutzername, das Passwort sowie der Name und die Host-Adresse der Datenbank richtig sind und ob dieser Benutzer Zugriff auf die angegebene Datenbank hat.';
 $lang['cannot_write_config'] = 'Fehler: Kann nicht in die Datei %s schreiben.';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple - Informationen zum Administrator-Konto';
 $lang['email_accountinfo_message'] = 'Vielen Dank f&uuml;r die Installation von CMS made simple.
@@ -330,5 +332,8 @@ Benutzername: %s
 Passwort: %s
 
 In die Administration Ihrer Seite gelangen Sie hier: %s';
-$lang['utma'] = '156861353.717462736.1147511856.1213780620.1213782764.320';
+$lang['utma'] = '156861353.717462736.1147511856.1249117058.1249133074.380';
+$lang['utmz'] = '156861353.1245564627.365.3.utmccn=(referral)|utmcsr=just4test.de|utmcct=/amiga/listmodules.php|utmcmd=referral';
+$lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
