@@ -1,4 +1,6 @@
 <?php
+$lang['invalidemail'] = 'L&#039;indirizo email inserito non &egrave; valido';
+$lang['empty_query'] = 'Query vuota?? %s';
 $lang['no_db_driver'] = 'Nessun DB drivers compatibile trovato in CMSMS?';
 $lang['test_check_output_buffering'] = 'Contollo del output buffering';
 $lang['test_check_output_buffering_failed'] = 'Output buffering &egrave; disabilitato. Probabilmente non sarete in grado di usare molte funzionalit&agrave; che vengono rivhieste da questo.';
@@ -187,7 +189,7 @@ $lang['install_thanks'] = 'Grazie per l&#039;installazione di CMS Made Simple';
 $lang['upgrade_title'] = 'Aggiornamento di CMS Made Simple (passo %s)';
 $lang['upgrade_system'] = 'Sistema di aggiornamento';
 $lang['upgrade_thanks'] = 'Grazie per l&#039;aggiornamento di CMS Made Simple a';
-$lang['install_please_read'] = 'Si prega di leggere le pagine sulle <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Problematiche di Installazione</a> nella documentazione di CMS Made Simple Documentation Wiki.';
+$lang['install_please_read'] = 'Si prega di leggere le pagine sulle <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting">Problematiche di Installazione</a> nella documentazione di CMS Made Simple Documentation Wiki.';
 $lang['install_checking'] = 'Controllo dei permessi e delle configurazioni di PHP';
 $lang['install_test'] = 'Test';
 $lang['install_result'] = 'Risultati';
@@ -330,8 +332,8 @@ username: %s
 password: %s
 
 Potete entrare qui nell&#039;area di amministrazione: %s';
-$lang['utmz'] = '156861353.1228168733.609.121.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
-$lang['utma'] = '156861353.1807151640.1182960456.1227740242.1228168733.609';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.880130626.1236353467.1242837027.1242854657.40';
+$lang['utmz'] = '156861353.1242854657.40.35.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
