@@ -1,4 +1,6 @@
 <?php
+$lang['invalidemail'] = 'E-postadressen som er oppgitt er ugyldig';
+$lang['empty_query'] = 'Tom sp&oslash;rring?? %s';
 $lang['no_db_driver'] = 'Ingen kompatible databasedrivere ble funnet';
 $lang['test_check_output_buffering'] = 'Tester for output buffring';
 $lang['test_check_output_buffering_failed'] = 'Output buffring er avsl&aring;tt. Du vil trolig f&aring;r problemer med &aring; benytte de funksjoner som benytter denne funksjonen';
@@ -66,27 +68,27 @@ $lang['upload_file_no_readable'] = 'Opplastet fil er ikke lesbar!';
 $lang['upload_file_multiple'] = 'Flere filopplastinger ikke tillatt!';
 $lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operasjoner';
 $lang['test_check_magic_quotes_gpc_failed'] = 'N&aring;r magic_quotes er p&aring;, vil alle apostrofer, anf&oslash;rselstegn og omvendt skr&aring;strek bli markert(escaped) med omvendt skr&aring;strek automatisk. Kan ogs&aring; ha problemer med lagring av maler.';
-$lang['test_check_magic_quotes_runtime'] = 'Magic quotes er aktivert';
+$lang['test_check_magic_quotes_runtime'] = 'Test om Magic quotes er aktivert';
 $lang['test_check_magic_quotes_runtime_failed'] = 'N&aring;r magic_quotes er p&aring;, vil de fleste funksjoner som returnerer data fra enhver form for ekstern kilde - inkludert databaser og tekstfiler ha anf&oslash;rselstegn markert(escaped) med omvendt skr&aring;strek. Dette vil gi problemer med CMS Made Simple.';
 $lang['install_admin_checksum'] = 'Test din installasjon';
 $lang['upgrade_admin_checksum'] = 'Test din systemoppgradering';
-$lang['checksum'] = 'Testsum test ';
-$lang['checksum_file'] = 'Testsum fil';
-$lang['install_test_checksum'] = 'Du kan teste integriteten for dine CMS filer ved &aring; sammenligne mot en original CMS testsum. Dette kan hjelpe til med &aring; finne problem med opplasting.';
-$lang['checksum_passed'] = 'Alle testsum&#039;er er like!';
-$lang['checksum_failed'] = 'Testsum hadde feil. Se i hjelp for mer informasjon';
+$lang['checksum'] = 'Checksum test ';
+$lang['checksum_file'] = 'Checksum fil';
+$lang['install_test_checksum'] = 'Du kan teste integriteten for dine CMS filer ved &aring; sammenligne mot en original CMS checksum. Dette kan hjelpe til med &aring; finne problemer med opplastinger.';
+$lang['checksum_passed'] = 'Alle checksum&#039;er er like!';
+$lang['checksum_failed'] = 'Checksum hadde feil. Se i hjelp for mer informasjon';
 $lang['test_check_open_basedir'] = 'Test for PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Open basedir restriksjoner er effektive. Du vil trolig ha problemer med noe tilleggsfunksjonalitet med denne restriksjonen.';
 $lang['unlimited'] = 'Ubegrenset';
 $lang['test_open_basedir_session_save_path'] = 'Open basedir restriksjoner ser ut til &aring; v&aelig;re i effekt. Om du har SESSION problemer og ini_set fungerer kan du fors&oslash;ke &aring; sl&aring; p&aring; session cookies ved &aring; legge til: ini_set(&#039;session.use_only_cookies&#039;, 1); til toppen av include.php fila';
 $lang['install_warn_db_createtables'] = 'Normal skal dette feltet alltid v&aelig;re avkrysset. V&aelig;r forsiktig om du sl&aring;r av denne egenskapen.';
 $lang['install_admin_tablesnotcreated'] = 'Prosessering ferdig. Installasjonsprosessen er fullf&oslash;rt, p&aring; din begj&aelig;ring ble ikke databasetabeller opprettet. Men config filen har blitt tilbakestilt og alle f&oslash;r-installasjonstester ble gjennomf&oslash;rt. Takk, og her er din';
-$lang['info_create_dir_and_file'] = 'HTTP prosessens eier kan ikke opprette en fil inne ,i en katalog som den eier. Dette betyr sannsynligvis at safe mode er sl&aring;tt p&aring; p&aring; en eller annen m&aring;te. Mange funksjoner inne i CMS Made Simple vil ikke fungere skikkelig uten denne muligheten. &Aring; fortsette er ikke mulig.';
+$lang['info_create_dir_and_file'] = 'HTTP prosessens eier kan ikke opprette en fil inne i en katalog som den eier. Dette betyr sannsynligvis at safe mode er sl&aring;tt p&aring; p&aring; en eller annen m&aring;te. Mange funksjoner inne i CMS Made Simple vil ikke fungere skikkelig uten denne muligheten. &Aring; fortsette er ikke mulig.';
 $lang['test_create_dir_and_file'] = 'Tester om http prosessen kan opprette en fil inne i en katalog den har opprettet.';
 $lang['cms_site'] = 'CMS nettsted';
 $lang['or_greater'] = 'Eller st&oslash;rre';
 $lang['sitename'] = 'Nettstedsnavn';
-$lang['warning_safe_mode'] = '<strong><em>ADVARSEL:</em></strong> PHP Safe_mode er p&aring;sl&aring;tt.  Dette vil medf&oslash;re problemer med filer som lastes opp via nettleser grensesnittet, inkludert bilder, tema og modul XML pakker. Du r&aring;des til  &aring; kontakte din nettstedsadministrator for &aring; se om safe_mode kan sl&aring;s av..';
+$lang['warning_safe_mode'] = '<strong><em>ADVARSEL:</em></strong> PHP Safe_mode er p&aring;sl&aring;tt.  Dette vil medf&oslash;re problemer med filer som lastes opp via nettleser grensesnittet, inkludert bilder, tema og modul XML pakker. Du r&aring;des til  &aring; kontakte din nettstedsadministrator for &aring; se om safe_mode kan sl&aring;s av.';
 $lang['test'] = 'Test ';
 $lang['results'] = 'Resultater';
 $lang['untested'] = 'Ikke testet';
@@ -153,7 +155,7 @@ $lang['description'] = 'Beskrivelse';
 $lang['directoryexists'] = 'Katalogen eksisterer allerede.';
 $lang['down'] = 'Ned';
 $lang['edit'] = 'Rediger';
-$lang['email'] = 'Epostadresse';
+$lang['email'] = 'E-postadresse';
 $lang['errordeletingfile'] = 'Kan ikke slette filen, Rettighetsproblem?';
 $lang['errordirectorynotwritable'] = 'Har ikke rettighet til &aring; skrive til katalog. Dette kan for&aring;rsakes av filrettigheter og eierskap. Safe_mode kan ogs&aring; v&aelig;re i effekt.';
 $lang['cachenotwritable'] = 'Cache mappen er ikke skrivbar. &Aring; t&oslash;mme cache vil ikke fungere. Vennligst endre tmp/cache katalogen til &aring; ha full lese/skrive/utf&oslash;re(read/write/execute) rettigheter (chmod 777). Du trenger kanskje ogs&aring; &aring; sl&aring; av safe mode.';
@@ -220,7 +222,7 @@ $lang['test_username_not_given'] = 'Brukernavn ikke oppgitt!';
 $lang['test_username_illegal'] = 'Brukernavn inneholder ugyldige bokstaver!';
 $lang['test_not_both_passwd'] = 'Begge passordfeltene ble ikke fylt ut';
 $lang['test_passwd_not_match'] = 'Passordfeltene samsvarer ikke!';
-$lang['test_email_accountinfo'] = 'Send kontoinformasjon via epost er valgt, men ingen epostadresse er oppgitt!';
+$lang['test_email_accountinfo'] = 'Send kontoinformasjon via e-post er valgt, men ingen e-postadresse er oppgitt!';
 $lang['test_database_prefix'] = 'Database forstavelse inneholder ugyldige bokstaver';
 $lang['test_no_dbms'] = 'Ingen dbms valgt!';
 $lang['test_could_not_connect_db'] = 'Kunne ikke koble til databasen. Sjekk at brukernavn og passord er korrekte, og at den brukeren har tilgang til den oppgitte databasen.';
@@ -275,12 +277,12 @@ $lang['test_check_session_save_path_failed'] = 'Din session.save_path er &quot;%
 $lang['test_check_ini_set'] = 'Sjekker om ini_set fungerer';
 $lang['test_check_ini_set_failed'] = 'Selv om muligheten til &aring; overstyre php ini innstillinger ikke er n&oslash;dvendig, noen tillegg (valgfri) funksjonalitet benytter ini_set for &aring; utvide tidsavbrudd, og tillater da opplasting av st&oslash;rre filer, osv. Du kan f&aring; vanskeligheter med noen tilleggsfunksjoner om du ikke har denne muligheten. Denne testen kan feile om safe_mode er aktivert (se nedenfor).';
 $lang['install_admin_header'] = 'Admin kontoinformasjon';
-$lang['install_admin_info'] = 'Velg brukernavn, passord og epostadresse for din adminkonto. Vennligst pass p&aring; at du tar godt vare p&aring; denne informasjonen da det ikke vil v&aelig;re noen annen m&aring;te &aring; logge inn i din CMS Made Simple administrasjonsystem uten dette.';
-$lang['install_admin_email'] = 'Epostadresse';
-$lang['install_admin_email_info'] = 'Epostkonto informasjon';
-$lang['install_admin_email_note'] = '<strong>Merk:</strong> Denne funksjonen benytter php&#039;s epostfunksjon. Om du ikke mottar denne eposten, kan det v&aelig;re en indikasjon p&aring; at din server ikke er godt konfigurert og at du b&oslash;r kontakte din vert administrator.';
+$lang['install_admin_info'] = 'Velg brukernavn, passord og e-postadresse for din adminkonto. Vennligst pass p&aring; at du tar godt vare p&aring; denne informasjonen.';
+$lang['install_admin_email'] = 'E-postadresse';
+$lang['install_admin_email_info'] = 'E-post kontoinformasjon';
+$lang['install_admin_email_note'] = '<strong>Merk:</strong> Denne funksjonen benytter php&#039;s e-postfunksjon. Om du ikke mottar denne e-posten, kan det v&aelig;re en indikasjon p&aring; at din server ikke er godt konfigurert og at du b&oslash;r kontakte din vert administrator.';
 $lang['install_admin_sitename'] = 'Dette er navnet p&aring; ditt nettsted. Det vil bli benyttet p&aring; forskjellige plasser i standard malene og kan benyttes hvor som helst med taggen {sitename}.';
-$lang['install_admin_db'] = 'Database informasjon';
+$lang['install_admin_db'] = 'Databaseinformasjon';
 $lang['install_admin_db_info'] = '<p>V&aelig;r sikker p&aring; at du har opprettet din database og har tilegnet en bruker fulle privileger for &aring; benytte denne databasen.</p>
 <p>For MySQL, benytt f&oslash;lgende:</p>
 <p>Logg inn i mysql fra et konsoll og kj&oslash;r f&oslash;lgende kommandoer:</p>
@@ -307,7 +309,7 @@ $lang['failed'] = 'feilet';
 $lang['install_admin_error_schema'] = 'Feil ved henting av SQL schema';
 $lang['install_admin_set_account'] = 'Skriver admin kontoinformasjon...';
 $lang['install_admin_set_sitename'] = 'Skriver nettstedsnavn...';
-$lang['install_admin_setup'] = 'N&aring; la oss fortsette &aring; sette opp din konfigurasjonsfil. Vi har allerede det meste vi trenger. Det er mulig du kan la de kommende verdier v&aelig;re som de er, s&aring; n&aring;r du er klar - trykk Fortsett.';
+$lang['install_admin_setup'] = 'N&aring; la oss fortsette &aring; sette opp din konfigurasjonsfil. Vi har allerede det meste vi trenger. Det er mulig du kan la de f&oslash;lgende verdier v&aelig;re som de er, s&aring; n&aring;r du er klar - trykk Fortsett.';
 $lang['install_admin_docroot'] = 'CMS dokumentrot (som sett fra webservveren)';
 $lang['install_admin_docroot_path'] = 'Sti til Dokumentrota(Document root)';
 $lang['install_admin_querystring'] = 'Query string (ikke r&oslash;r denne om du ikke har problemer, om s&aring; - rediger config.php manuelt)';
@@ -318,7 +320,7 @@ $lang['install_admin_set_core_event'] = 'Setter opp core handlinger...';
 $lang['install_admin_install_modules'] = 'Installerer moduler...';
 $lang['install_admin_index_search'] = 'Indekserer s&oslash;k...';
 $lang['install_admin_clear_cache'] = 'T&oslash;mmer nettsteds cache (om finnes)...';
-$lang['install_admin_emailing'] = 'Sender admin kontoinnstillinger via epost...';
+$lang['install_admin_emailing'] = 'Sender admin kontoinnstillinger via e-post...';
 $lang['install_admin_congratulations'] = 'Gratulerer, n&aring; er alt ferdig satt opp - her er ditt';
 $lang['could_not_connect_db'] = 'Kunne ikke koble til databasen. Sjekk at brukernavn og passord er korrekte, og at denne brukeren har tilgang til den oppgitte databasen.';
 $lang['cannot_write_config'] = 'Feil: kan ikke skrive til %s.';
@@ -330,8 +332,8 @@ brukernavn: %s
 passord: %s
 
 Logg inn i nettstedets administrasjon her: %s';
-$lang['utma'] = '156861353.179052623084110100.1210423577.1232212897.1232219331.832';
-$lang['utmz'] = '156861353.1227995283.716.23.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
+$lang['utmz'] = '156861353.1245190196.1444.36.utmcsr=themes.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/download_themes.html';
+$lang['utma'] = '156861353.179052623084110100.1210423577.1245587444.1245590676.1462';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1232219331';
+$lang['utmb'] = '156861353.1.10.1245590676';
 ?>
\ No newline at end of file
