@@ -1,7 +1,9 @@
 <?php
+$lang['invalidemail'] = 'Het ingevoerde email adres is niet correct';
+$lang['empty_query'] = 'Lege query?? %s';
 $lang['no_db_driver'] = 'Geen bruikbare database drivers gevonden';
 $lang['test_check_output_buffering'] = 'Controleer output buffering';
-$lang['test_check_output_buffering_failed'] = 'Output buffering is uitgeschakeld. Waarschijnlijk werken niet alle functionaliteit die deze benodigd';
+$lang['test_check_output_buffering_failed'] = 'Output buffering is uitgeschakeld. Waarschijnlijk werken niet alle functionaliteit die deze benodigd.';
 $lang['phpinfo'] = 'Bekijken van PHP informatie';
 $lang['mod_security'] = 'Apache Mod Beveiliging';
 $lang['test_check_tempnam'] = 'Controle op tempnam functie';
@@ -10,7 +12,7 @@ $lang['test_check_db_drivers_failed'] = 'Geen database drivers gevonden';
 $lang['test_check_register_globals'] = 'Controleren van PHP register globals';
 $lang['test_check_register_globals_failed'] = 'PHP register globals zijn actief. Voor beveiligingsredenen moet u dit uitschakelen.';
 $lang['test_check_disable_functions'] = 'Controleren voor uitstaande PHP functies.';
-$lang['test_check_disable_functions_failed'] = 'Deze lijst bevat alle uitgeschakelende PHP functies op uw server.';
+$lang['test_check_disable_functions_failed'] = 'Deze lijst bevat alle uitgeschakelde PHP functies op uw server.';
 $lang['install_admin_db_port'] = 'Database poort';
 $lang['install_admin_db_port_info'] = 'Als u het niet weet, laat het dan bij de bestaande instellingen';
 $lang['install_admin_db_socket'] = 'Database socket ';
@@ -38,16 +40,16 @@ $lang['noneed_upgrade_modules'] = 'De core modules zijn bijgewerkt';
 $lang['upgrade_sql_module_from_to'] = 'Bijwerken SQL van &quot;%s&quot; module van %s naar %s ...';
 $lang['upgrade_event_module_from_to'] = 'Bijwerken Events van &quot;%s&quot; module van %s naar %s ...';
 $lang['sitedown_not_removed'] = 'Kan tmp/cache/SITEDOWN bestand niet verwijderen. Verwijder dit bestand handmatig of anders zal uw site een &quot;Site Down for Maintenance&quot; melding weergeven.';
-$lang['upgrade_ok'] = 'Controleer config.php, wijzig enkele nieuwe instellingen en stel het bestand daarna weer in als &#039;Alleen lezen&#039;. U moet ook controleren of al uw modules up-to-date zijn. Hiervoor gaat u naar Uitbereidingen -> Modules en zoek in de lijst naar &#039;Vereist Upgrade&#039;.';
-$lang['upgrade_complete'] = 'Updateproces voltooid';
+$lang['upgrade_ok'] = 'Controleer uw config.php, wijzig enkele nieuwe instellingen en stel het bestand daarna weer in als &#039;Alleen lezen&#039; (444). U moet ook controleren of al uw modules up-to-date zijn. Hiervoor gaat u naar Uitbreidingen -> Modules en zoek in de lijst naar &#039;Vereist Upgrade&#039;.';
+$lang['upgrade_complete'] = 'Update proces voltooid';
 $lang['upgrade_end'] = 'CMS is up-to-date. Klik op %s om naar uw CMS site te gaan of ga naar %s.';
 $lang['here'] = 'hier';
-$lang['go_to_admin'] = 'ga naar het Administratorpaneel';
+$lang['go_to_admin'] = 'ga naar het Beheerpaneel';
 $lang['errorfilenot'] = 'Bestand niet gevonden!';
 $lang['errorfilenotwritable'] = 'Bestand niet beschrijfbaar!';
 $lang['nofiles'] = 'Deze bron bestaat niet!';
 $lang['is_directory'] = 'Deze bron is een map!';
-$lang['is_readable_false'] = 'Deze bron us niet leesbaar!';
+$lang['is_readable_false'] = 'Deze bron is niet leesbaar!';
 $lang['checksum_match'] = 'Checksum klopt!';
 $lang['checksum_not_match'] = 'Checksum komt niet overeen!';
 $lang['not_checksum'] = 'Geen checksum gevonden!';
@@ -55,35 +57,35 @@ $lang['format_datetime'] = '%c ';
 $lang['upload_err_ini_size'] = 'Het ge&uuml;ploade bestand overschrijdt upload_max_filesize instelling in php.ini!';
 $lang['upload_err_form_size'] = 'Het ge&uuml;ploade bestand overschrijdt MAX_FILE_SIZE instelling die is op gegeven in het HTML formulier.';
 $lang['upload_err_partial'] = 'Het ge&uuml;ploade bestand is slechts gedeeltelijk geupload.';
-$lang['upload_err_no_file'] = 'Er is geen bestand geupload.';
+$lang['upload_err_no_file'] = 'Er is geen bestand ge&uuml;pload.';
 $lang['upload_err_no_tmp_dir'] = 'Mist een tijdelijke map.';
 $lang['upload_err_cant_write'] = 'Fout bij het wegschrijven van bestand naar schijf.';
 $lang['upload_err_extension'] = 'Bestandupload gestopt door extensie.';
-$lang['upload_err_empty'] = 'Bestand heeft geen grootte.';
+$lang['upload_err_empty'] = 'Bestand heeft geen grootte (0kb).';
 $lang['upload_err_unknown'] = 'Onbekende uploadfout.';
-$lang['function_file_uploads_off'] = 'file_uploads is uitgeschakeld in uw php!';
-$lang['upload_file_no_readable'] = 'Bestandsupload onleesbaar.';
+$lang['function_file_uploads_off'] = 'file_uploads is uitgeschakeld in uw php configuratie!';
+$lang['upload_file_no_readable'] = 'Ge&uuml;pload bestand is onleesbaar.';
 $lang['upload_file_multiple'] = 'Meerdere bestandsuploads zijn niet toegestaan!';
 $lang['test_check_magic_quotes_gpc'] = 'Magic quotes voor Get/Post/Cookie operaties';
-$lang['test_check_magic_quotes_gpc_failed'] = 'Enkele aanhalingstekens, dubbele aanhalingstekens en backslashes worden automatisch verwijderd. U kunt daardoor problemen krijgen bij het opslaan van templates.';
+$lang['test_check_magic_quotes_gpc_failed'] = 'Enkele aanhalingstekens, dubbele aanhalingstekens en backslashes worden automatisch verwijderd. U kunt daardoor problemen krijgen bij het gebruik van het CMS.';
 $lang['test_check_magic_quotes_runtime'] = 'Er bevinden zich magic quotes in de runtime.';
 $lang['test_check_magic_quotes_runtime_failed'] = 'Als magic_quotes zijn ingeschakeld, zullen de meeste functies data met elke soort van externe verbinding, inclusief databases en teksbestanden, de quotes vervangen met een backslash. Dit kan problemen veroorzaken.';
 $lang['install_admin_checksum'] = 'Controleer uw installatie';
 $lang['upgrade_admin_checksum'] = 'Controleer uw systeemupgrade';
 $lang['checksum'] = 'Checksum test ';
 $lang['checksum_file'] = 'Checksum bestand';
-$lang['install_test_checksum'] = 'U kunt de echtheid van de bestanden van uw CMS vergelijken met de orginele bestanden doormiddel van een checksum. Het kan helpen met het opsporen van problemen bij uploads.';
+$lang['install_test_checksum'] = 'U kunt de echtheid van de bestanden van uw CMS vergelijken met de originele bestanden door middel van een checksum. Het kan helpen met het opsporen van problemen bij uploads.';
 $lang['checksum_passed'] = 'Alle checksums kloppen!';
 $lang['checksum_failed'] = 'Checksum komt overeen met fouten. Kijk bij help voor meer informatie.';
 $lang['test_check_open_basedir'] = 'Controle op &#039;PHP Open Basedir&#039;';
 $lang['test_check_open_basedir_failed'] = '&#039;Open basedir&#039; beperking is actief. Sommige additionele functionaliteiten kunnen hierdoor beperkt werken.';
 $lang['unlimited'] = 'Ongelimiteerd';
-$lang['test_open_basedir_session_save_path'] = '&#039;Open basedir&#039; beperkingen lijken van invloed te zijn. Als u SESSION problemen krijgt en ini_set is toepasbaar, kunt u proberen om sessions door middel van cookies aan te zetten door: ini_set(&#039;session.use_only_cookies&#039;, 1);  boven in het include.php bestand te plaatsen.';
+$lang['test_open_basedir_session_save_path'] = '&#039;Open basedir&#039; beperkingen lijken van invloed te zijn. Als u SESSION problemen krijgt en ini_set is toepasbaar, kunt u proberen om sessions door middel van cookies aan te zetten door: ini_set(&#039;session.use_only_cookies&#039;, 1);  boven in het config.php bestand te plaatsen.';
 $lang['install_warn_db_createtables'] = 'Normaal dient dit veld aangevinkt te zijn. Wees voorzichtig met het uitschakelen van deze optie.';
 $lang['install_admin_tablesnotcreated'] = 'Proces gereed. De installatie is klaar. Op je verzoek zijn geen tabellen aangemaakt. De config.php is echter ge-reset en alle pre-installatie testen zijn gedaan. Bedankt en hier is je';
 $lang['info_create_dir_and_file'] = 'De HTTP proces eigenaar kan geen bestand aanmaken in een directory waar deze eigenaar van is. Dit betekent waarschijnlijk dat safe mode is ingeschakeld. Veel functies binnen CMS Made Simple zullen waarschijnlijk niet goed werken als dit niet mogelijk is. Doorgaan is niet mogelijk.';
 $lang['test_create_dir_and_file'] = 'Controleert of het httpd proces een bestand kan aanmaken in een (door het proces) aangemaakte directory.';
-$lang['cms_site'] = 'CMS Site ';
+$lang['cms_site'] = 'CMS Website ';
 $lang['or_greater'] = 'Of groter';
 $lang['sitename'] = 'Website naam';
 $lang['warning_safe_mode'] = '<strong><em>WAARSCHUWING:</em></strong> PHP Safe mode is ingeschakeld. Dit geeft problemen bij het uploaden van bestanden middels de web browser interface, waaronder afbeeldingen, thema&#039;s en module XML installaties. Het is aangeraden contact op te nemen met de systeem beheerder en safe mode uit te laten schakelen.';
@@ -103,7 +105,7 @@ $lang['session_save_path'] = 'Opslagpad voor sessie';
 $lang['max_execution_time'] = 'Maximale Uitvoer Tijd';
 $lang['gd_version'] = 'GD versie';
 $lang['upload_max_filesize'] = 'Maximale Upload Grootte';
-$lang['post_max_size'] = 'Maximale Post Size';
+$lang['post_max_size'] = 'Maximale Post Grootte';
 $lang['memory_limit'] = 'PHP Memory Limit ';
 $lang['server_db_type'] = 'Server Database ';
 $lang['server_db_version'] = 'Server Database Versie';
@@ -112,10 +114,10 @@ $lang['safe_mode'] = 'PHP Safe Mode ';
 $lang['php_information'] = 'PHP Informatie';
 $lang['cms_install_information'] = 'CMS Installatie informatie';
 $lang['cms_version'] = 'CMS Versie';
-$lang['systeminfo_copy_paste'] = 'Kopieer en plak deze geselecteerde tekst in je';
-$lang['help_systeminformation'] = 'De hieronder getoonde informatie, uit verschillende elementen van het systeem, kunnen worden gebruikt kunnen worden bij probleem-analyse.';
+$lang['systeminfo_copy_paste'] = 'Kopieer en plak deze geselecteerde tekst in je forum bericht';
+$lang['help_systeminformation'] = 'De hieronder getoonde informatie, uit verschillende elementen van het systeem, kunnen worden gebruikt bij probleem analyse van uw CMS Made Simple website.';
 $lang['systeminfo'] = 'Systeem Informatie';
-$lang['systeminfodescription'] = 'Tonen van verschillende informatie elementen van het systeem die kunnen worden gebruikt bij probleem-analyse';
+$lang['systeminfodescription'] = 'Tonen van verschillende informatie elementen van het systeem die kunnen worden gebruikt bij probleem analyse';
 $lang['error'] = 'Fout';
 $lang['new_version_available'] = '<em>Opmerking:</em> Er is een nieuwere versie van het CMS beschikbaar. Neem contact op met uw webmaster.';
 $lang['info_urlcheckversion'] = 'Wanneer  &quot;none&quot; wordt opgegeven wordt geen controle gedaan .<br/>Een lege URL zal gebruik maken van de standaard-link.';
@@ -130,7 +132,7 @@ $lang['errorcantcreatefile'] = 'Kan geen bestand aanmaken (rechtenprobleem?)';
 $lang['add'] = 'Toevoegen';
 $lang['about'] = 'Over';
 $lang['action'] = 'Actie';
-$lang['actionstatus'] = 'Actie/ Status';
+$lang['actionstatus'] = 'Actie / Status';
 $lang['active'] = 'Actief';
 $lang['cantremove'] = 'Kan niet verwijderen';
 $lang['changepermissions'] = 'Wijzig rechten';
@@ -139,11 +141,11 @@ $lang['success'] = 'Succes';
 $lang['advanced'] = 'Geavanceerd';
 $lang['back'] = 'Terug naar Menu';
 $lang['cancel'] = 'Annuleren';
-$lang['cantchmodfiles'] = 'Could not change permissions on some files';
+$lang['cantchmodfiles'] = 'Kon de rechten op sommige bestanden niet wijzigen.';
 $lang['cantremovefiles'] = 'Probleem bij het verwijderen van bestanden (rechten?)';
 $lang['create'] = 'Maak';
 $lang['database'] = 'Database ';
-$lang['databaseprefix'] = 'Database Prefix ';
+$lang['databaseprefix'] = 'Database Prefix (voorvoegsel)';
 $lang['databasetype'] = 'Database Type ';
 $lang['date'] = 'Datum';
 $lang['default'] = 'Standaard';
@@ -153,7 +155,7 @@ $lang['description'] = 'Omschrijving';
 $lang['directoryexists'] = 'Deze directory bestaat al';
 $lang['down'] = 'Beneden';
 $lang['edit'] = 'Bewerk';
-$lang['email'] = 'Email Adres';
+$lang['email'] = 'E-mail Adres';
 $lang['errordeletingfile'] = 'Kan bestand niet verwijderen. Controleer of dit een rechtenprobleem is.';
 $lang['errordirectorynotwritable'] = 'Geen rechten om in map te schrijven. Dit kan veroorzaakt worden door bestands- en eigendomsrechten. De veilige modus (PHP safe mode) kan ook aanstaan.';
 $lang['cachenotwritable'] = 'De cachemap is niet schrijfbaar. Het legen van de cache is niet mogelijk. Zorg dat de map tmp/cache volledig lees/schrijf/uitvoer rechten heeft (chmod 777). Ook kan het nodig zijn de veilige modus (PHP safe mode) uit te schakelen.';
@@ -171,26 +173,26 @@ $lang['passwordagain'] = 'Wachtwoord ( opnieuw )';
 $lang['remove'] = 'Verwijderen';
 $lang['saveconfig'] = 'Configuratie opslaan';
 $lang['true'] = 'Waar';
-$lang['setfalse'] = 'Ze op onwaar';
+$lang['setfalse'] = 'Zet op onwaar';
 $lang['type'] = 'Type ';
 $lang['typenotvalid'] = 'Type is niet correct';
 $lang['unknown'] = 'Onbekend';
 $lang['user'] = 'Gebruiker';
-$lang['userdefinedtags'] = 'Gebruikergedefinieerde tags';
+$lang['userdefinedtags'] = 'Gebruikergedefinieerde tags (UDT)';
 $lang['usermanagement'] = 'Gebruikersbeheer';
 $lang['username'] = 'Gebruikersnaam';
 $lang['usernameincorrect'] = 'Gebruikersnaam of wachtwoord zijn niet correct';
 $lang['version'] = 'Versie';
-$lang['install_title'] = 'CMS Installatie (step %s)';
+$lang['install_title'] = 'CMS Made Simple Installatie (stap %s)';
 $lang['install_system'] = 'Installeer Systeem';
-$lang['install_thanks'] = 'Bedankt voor het installeren van het CMS';
+$lang['install_thanks'] = 'Bedankt voor het installeren van CMS Made Simple.';
 $lang['upgrade_title'] = 'CMS Made Simple Upgrade (stap %s)';
-$lang['upgrade_system'] = 'Upgraden van systeem';
+$lang['upgrade_system'] = 'Upgraden van het systeem';
 $lang['upgrade_thanks'] = 'Bedankt voor het upgraden van CMS Made Simple naar';
 $lang['install_please_read'] = 'Lees de <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting" > Installation Troubleshooting </a> pagina in het CMS Made Simple Documentatie Wiki.';
-$lang['install_checking'] = 'Controleer toestemming en PHP instellingen';
+$lang['install_checking'] = 'Controleer rechten en PHP instellingen';
 $lang['install_test'] = 'Test ';
-$lang['install_result'] = 'Resultaten';
+$lang['install_result'] = 'Resultaat';
 $lang['install_required_settings'] = 'Verplichte instellingen';
 $lang['install_recommended_settings'] = 'Aanbevolen instellingen';
 $lang['install_you_have'] = 'U hebt';
@@ -202,26 +204,26 @@ $lang['install_value_failed'] = 'Een verplichte test is mislukt';
 $lang['install_error_fragment'] = 'Info Hulp bij Installatie';
 $lang['install_value_required'] = 'Een instelling voldoet niet aan de minimale eisen';
 $lang['install_value_recommended'] = 'Een instelling is boven de vereiste, maar onder de aanbevolen waarde<br />of... een onderdeel dat <em>mischien</em> vereist is voor optionele functionaliteit is niet beschikbaar';
-$lang['install_value_exceed'] = 'Een instelling valt binnen of boven de aanbevolen drempelwaardes<br />of... een onderdeel dat <misschien> vereist is voor optionele functionaliteit is beschikbaar
+$lang['install_value_exceed'] = 'Een instelling valt binnen of boven de aanbevolen drempelwaardes<br />of... een onderdeel dat <em>misschien<em> vereist is voor optionele functionaliteit is beschikbaar
 ';
 $lang['install_test_failed'] = 'Een of meer van de tests zijn niet gelukt. Het systeem kan wel geinstalleerd worden, maar sommige functionaliteiten zullen misschien niet correct functioneren.<br />Probeer de situatie te corrigeren en klik op &quot;Probeer opnieuw&quot;, of klik op &quot;Volgende&quot;.
 ';
-$lang['install_test_passed'] = 'Alle testen zijn gelukt (op minimaal niveau). Klik de Volgende button.';
-$lang['install_failed_again'] = 'Een of meer testen zijn mislukt. Herstel de problemen en probeer het opnieuw.';
+$lang['install_test_passed'] = 'Alle testen zijn gelukt (in ieder geval op het minimale niveau). Klik de &quot;Volgende&quot; button.';
+$lang['install_failed_again'] = 'E&eacute;n of meer testen zijn mislukt. Herstel de problemen en voer de test opnieuw uit.';
 $lang['install_try_again'] = 'Probeer opnieuw';
 $lang['install_continue'] = 'Volgende';
 $lang['failure'] = 'Mislukt';
 $lang['caution'] = 'Voorzichtig';
 $lang['install_admin_umask'] = 'Test umask server';
-$lang['install_test_umask'] = 'Klik de Test knop om te controleren  ...';
+$lang['install_test_umask'] = 'Klik de Test knop om te controleren ...';
 $lang['test_umask_text'] = 'umask (afgekort van user file creation mode mask) is een functie in POSIX omgevingen die de standaard systeem instellingen voor nieuw (door het huidige proces) aangemaakte bestanden en directories beinvloedt. Het bepaalt welke bestands permissies niet worden ingesteld voor ieder nieuw aangemaakt bestand.';
 $lang['test_check_umask'] = 'Resultaat test op bestand aangemaakt in';
 $lang['test_umask_not_given'] = 'Umask niet opgegeven';
 $lang['test_check_umask_failed'] = 'Test umask mislukt';
 $lang['test_username_not_given'] = 'Gebruikersnaam niet opgegeven!';
 $lang['test_username_illegal'] = 'Gebruikersnaam bevat verkeerde tekens!';
-$lang['test_not_both_passwd'] = 'U heeft niet beide wachtwoord velden ingevuld!';
-$lang['test_passwd_not_match'] = 'Wachtwoord komt niet overeen!';
+$lang['test_not_both_passwd'] = 'U heeft niet beide wachtwoordvelden ingevuld!';
+$lang['test_passwd_not_match'] = 'Wachtwoorden komen niet overeen!';
 $lang['test_email_accountinfo'] = 'E-mail accountinfo geselecteerd, maar geen e-mail adres opgegeven!';
 $lang['test_database_prefix'] = 'Database voorvoegsel bevat foutieve karakters';
 $lang['test_no_dbms'] = 'Geen dbms geselecteerd!';
@@ -229,9 +231,9 @@ $lang['test_could_not_connect_db'] = 'Kan geen verbinding maken met de database.
 $lang['test_could_not_drop_table'] = 'Niet mogelijk tabel te verwijderen. Controleer de rechten van de gebruiker op de database.';
 $lang['test_could_not_create_table'] = 'Niet mogelijk tabel aan te maken. Controleer de rechten van de gebruiker op de database.';
 $lang['test_check_php'] = 'Controleer voor PHP versie %s+';
-$lang['test_min_recommend'] = '(min %s, aanbevolen %s)';
-$lang['test_min_recommend_plus'] = '(min %s, aanbevolen %s+)';
-$lang['test_requires_php_version'] = 'CMS Made Simple heeft een php versie nodig van 4.3 of hoger (je hebt %s), maar PHP %s of hoger is aanbevolen voor de beste prestaties';
+$lang['test_min_recommend'] = '(minimaal %s, aanbevolen %s of hoger)';
+$lang['test_min_recommend_plus'] = '(minimaal %s, aanbevolen %s+)';
+$lang['test_requires_php_version'] = 'CMS Made Simple heeft een php versie nodig van 4.3 of hoger (u heeft %s), maar PHP %s of hoger is aanbevolen voor de beste prestaties bij het gebruik van modules van derden';
 $lang['test_check_md5_func'] = 'Controleren op md5-funktie';
 $lang['test_check_safe_mode'] = 'Controle op safe mode';
 $lang['test_check_safe_mode_failed'] = 'PHP veilige modus kan voor problemen met het uploaden van bestanden en andere functies. Het hangt allemaal af van hoe streng je server veilige modus instellingen zijn.';
@@ -240,9 +242,9 @@ $lang['test_check_tokenizer_failed'] = 'Als u geen tokenizer heeft, kunnen pagin
 $lang['test_check_gd'] = 'Controle van GD bibliotheek';
 $lang['test_check_gd_failed'] = 'GD bibliotheek is verplicht voor sommige modules en funtionaliteiten.';
 $lang['test_check_write'] = 'Controle van schrijfrechten in';
-$lang['test_may_not_exist'] = 'Het is mogelijk dat dit bestand niet bestaat. Wanneer deze niet bestaat, creeer een leeg bestand met deze naam. Zorg dat het webserver proces schrijfrechten heeft.';
-$lang['could_not_retrieve_a_value'] = 'Geen waarde opgehaald..... verwerking gaat verder.';
-$lang['displaying_the_value_originally'] = '<br />Toont de originele waarde in het configuratie-bestand (deze hoeft niet aktueel te zijn).';
+$lang['test_may_not_exist'] = 'Het is mogelijk dat dit bestand niet bestaat. Wanneer deze niet bestaat, cre&euml;er een leeg bestand met deze naam. Zorg dat het webserver proces schrijfrechten heeft.';
+$lang['could_not_retrieve_a_value'] = 'Geen waarde opgehaald... verwerking gaat verder.';
+$lang['displaying_the_value_originally'] = '<br />Toont de originele waarde in het configuratie-bestand (deze hoeft niet actueel te zijn).';
 $lang['test_check_xml_func'] = 'Controle van elementaire XML (expat) ondersteuning';
 $lang['test_check_xml_failed'] = 'XML ondersteuning is niet in de php installatie gecompileerd. Het systeem kan gebruikt worden, maar zal niet in staat zijn de module installatie functies &quot;op afstand&quot; van modulebeheer te gebruiken.
 ';
@@ -250,7 +252,7 @@ $lang['test_allow_url_fopen_failed'] = 'Als url fopen uitgeschakeld is zal het n
 ';
 $lang['test_remote_url'] = 'Test van externe URL';
 $lang['test_remote_url_failed'] = 'Het zal waarschijnlijk niet lukken een bestand op een andere/externe webserver te openen.';
-$lang['connection_error'] = 'Uitgaande http connecties, lijken niet te werken! Er is een firewall of ACL voor de externe aansluitingen? Dit zal resulteren in het niet werken van module manager, en mogelijk ook andere functies.';
+$lang['connection_error'] = 'Uitgaande http connecties lijken niet te werken! Er is een firewall of ACL voor de externe aansluitingen? Dit zal resulteren in het niet werken van module manager, en mogelijk ook andere functies.';
 $lang['remote_connection_timeout'] = 'Verbinden duurde te lang!';
 $lang['search_string_find'] = 'Verbinden geslaagd!';
 $lang['connection_failed'] = 'Verbinden mislukt!';
@@ -260,20 +262,20 @@ $lang['remote_response_error'] = 'Extern antwoord: Fout!';
 $lang['test_check_file_upload'] = 'Controle van bestand uploads';
 $lang['test_check_file_failed'] = 'Als bestand uploads uitgeschakeld zijn zal er geen gebruik gemaakt kunnen worden van de bestands upload faciliteiten van CMS Made Simple. Indien mogelijk moet deze beperking opgeheven worden om goed gebruik te kunnen maken van alle bestands management mogelijkheden. Ga door met de nodige voorzichtigheid.
 ';
-$lang['test_check_memory'] = 'Controle van PHP geheugen limiet (memory_limit)';
-$lang['test_check_memory_failed'] = 'Er is mischien niet genoeg geheugen beschikbaar voor PHP scripts om CMSMS correct te laten draaien, of alle gewenste uitbreidingen te gebruiken. Indien mogelijk, probeer de systeembeheerder deze waarde te laten verhogen. Ga door met de nodige voorzichtigheid.';
+$lang['test_check_memory'] = 'Controle van PHP geheugen limiet (php_memory_limit)';
+$lang['test_check_memory_failed'] = 'Er is mischien niet genoeg geheugen beschikbaar voor PHP scripts om CMSMS correct te laten functioneren, of alle gewenste uitbreidingen te gebruiken. Indien mogelijk, probeer de systeembeheerder deze waarde te laten verhogen. Ga door met de nodige voorzichtigheid.';
 $lang['test_check_time_limit'] = 'Controleren van PHP tijd limiet (time_limit) in seconden';
 $lang['test_check_time_limit_failed'] = 'Aantal seconden dat een script is toegestaan te draaien. Als dit wordt bereikt geeft het script een fatale fout.';
 $lang['test_check_post_max'] = 'Controle van maximale post grootte (max_post_size)';
 $lang['test_check_post_max_failed'] = 'Het zal waarschijnlijk niet mogelijk zijn (grotere hoeveelheden) data te versturen. Houd rekening met deze beperking.';
 $lang['test_check_upload_max'] = 'Controle van maximale upload bestandsgrootte (max_upload_file_size)';
 $lang['test_check_upload_max_failed'] = 'Het zal waarschijnlijk niet mogelijk zijn (grotere) bestanden te uploaden met de opgenomen bestands management functies. Houd rekening met deze beperking.';
-$lang['test_check_writable'] = 'Controleer of %s is beschrijfbaar';
+$lang['test_check_writable'] = 'Controleer of %s beschrijfbaar is';
 $lang['test_check_upload_failed'] = 'De Uploads map is niet beschrijfbaar. Je kan nog steeds het systeem installeren, maar het is dan niet mogelijk om bestanden te uploaden via het CMS.';
 $lang['test_check_images_failed'] = 'De Images map is niet beschrijfbaar. Je kan nog steeds het systeem installeren, maar het is dan niet mogelijk om images te uploaden via het CMS.';
 $lang['test_check_modules_failed'] = 'De modules map is niet beschrijfbaar. Je kan nog steeds het systeem installeren, maar het is dan niet mogelijk om modules te uploaden via het CMS.';
 $lang['test_check_file_get_contents'] = 'Controle van file_get_contents';
-$lang['test_check_file_get_contents_failed'] = 'De file_get_contents functie is toegevoegd in PHP 4.3 en hoewel er een workaround is gebruikt waardoor de meeste functionaliteit van deze functie goed zou moeten werken in PHP 4.2, is het aan te raden up te graden naar PHP 4.3 of hoger.';
+$lang['test_check_file_get_contents_failed'] = 'U zal hoogstwaarschijnlijk geen gebruik kunnen maken van functionaliteiten die deze functie gebruikt';
 $lang['test_check_session_save_path'] = 'Controleer of session.save_path beschrijfbaar is';
 $lang['test_empty_session_save_path'] = 'session.save_path is leeg. PHP gebruikt de tijdelijke directory van uw OS. Als er sessie problemen optreden en ini_set werkt, kunt u proberen sessie cookies in te schakelen door: ini_set(&quot;session.use_only_cookies&quot;, 1);  toe te voegen bovenaan in include.php';
 $lang['test_check_session_save_path_failed'] = 'session.save_path is &quot;%s&quot;. Als dit pad niet beschrijfbaar is kan inloggen op het beheerpaneel niet werken. Zorg ervoor dat dit pad schrijfbaar is als u problemen heeft met het inloggen op het beheerpaneel. Deze test kan falen als safe_mode is ingeschakeld (zie hieronder).';
@@ -285,7 +287,7 @@ $lang['install_admin_info'] = 'Selecteer de gebruikersnaam, wachtwoord en E-mail
 $lang['install_admin_email'] = 'E-mail Adres';
 $lang['install_admin_email_info'] = 'E-Mail Account Informatie';
 $lang['install_admin_email_note'] = '<strong>Let op:</strong> Deze functie gebruikt de php mail functie. Al u geen email ontvangt is dit een indicatie dat de server niet goed is geconfigureerd en u contact dient op te nemen met een systeembeheerder.';
-$lang['install_admin_sitename'] = 'Dit is de naam van je website. Het kan gebruikt worden op verschillende plaatsen in de templates of door deze	{sitename} tag.';
+$lang['install_admin_sitename'] = 'Dit is de naam van je website. Het kan gebruikt worden op verschillende plaatsen in de templates of door deze {sitename} tag.';
 $lang['install_admin_db'] = 'Database Informatie';
 $lang['install_admin_db_info'] = '<p>Zorg ervoor dat de database is aangemaakt en de database gebruiker volledige rechten heeft op het gebruik ervan.</p>
 <p>Voor MySQL vanuit console, doe het volgende:</p>
@@ -297,35 +299,35 @@ $lang['install_admin_db_info'] = '<p>Zorg ervoor dat de database is aangemaakt e
 $lang['install_admin_follow'] = 'Vul onderstaande velden in het geheel in';
 $lang['install_admin_db_type'] = 'Database Type ';
 $lang['install_admin_no_db'] = 'Er lijken geen ondersteunde database drivers in de PHP installatie te zijn gecompileerd. Verzeker uzelf ervan dat mysql, mysqli en/of postgres7 ondersteuning is geinstalleerd en probeer opnieuw.';
-$lang['install_admin_db_host'] = 'Database host address ';
+$lang['install_admin_db_host'] = 'Database hostadres ';
 $lang['install_admin_db_name'] = 'Database naam';
-$lang['install_admin_db_create'] = 'Maak tabellen (Waarschuwing: Verwijderd reeds opgeslagen data)';
+$lang['install_admin_db_create'] = 'Maak tabellen (Waarschuwing: Verwijdert reeds opgeslagen data)';
 $lang['install_admin_db_prefix'] = 'Tabel prefix';
 $lang['install_admin_db_sample'] = 'Installeer voorbeeld templates en teksten';
 $lang['retry'] = 'Opnieuw';
 $lang['install_admin_db_create_seq'] = 'Maak %s tabel sequence...';
-$lang['install_admin_importing'] = 'Importeer voorbeeld data...';
+$lang['install_admin_importing'] = 'Importeren voorbeeld data...';
 $lang['invalid_query'] = 'Ongeldige query: %s';
-$lang['install_creating_table'] = '<p>Maak %s tabel...</p>';
+$lang['install_creating_table'] = '<p>Maak %s tabel... [%s]</p>';
 $lang['install_creating_index'] = '<p>Maak index in %s tabel... [%s]</p>';
-$lang['done'] = 'klaar';
+$lang['done'] = 'gereed';
 $lang['failed'] = 'mislukt';
 $lang['install_admin_error_schema'] = 'Fout in ophalen van SQL schema';
 $lang['install_admin_set_account'] = 'Admin account informatie wordt ingesteld...';
-$lang['install_admin_set_sitename'] = 'Site naam wordt ingesteld... ';
+$lang['install_admin_set_sitename'] = 'Websitenaam wordt ingesteld... ';
 $lang['install_admin_setup'] = 'Instellen van het configuratie bestand. De meeste gegevens zijn bekend, de kans is groot dat deze waarden niet gewijzigd hoeven te worden. Controleer de gegevens en klik op &quot;Volgende&quot; als u klaar bent.';
-$lang['install_admin_docroot'] = 'CMS Document root (zoals gezien vanaf de webserver)';
-$lang['install_admin_docroot_path'] = 'Pad naar de Document root';
+$lang['install_admin_docroot'] = 'CMS Website root (zoals gezien vanaf de webserver)';
+$lang['install_admin_docroot_path'] = 'Pad naar de website root';
 $lang['install_admin_querystring'] = 'Query string (ongewijzigd laten tenzij u problemen ondervindt, bewerk dan config.php handmatig)';
 $lang['invalid_querys'] = '<b>WAARSCHUWING<b/>: Foute queries in de database!';
 $lang['install_admin_sitedown'] = 'Fout: Kan het bestand tmp/cache/SITEDOWN niet verwijderen. Verwijder deze handmatig.';
 $lang['install_admin_update_hierarchy'] = 'Bijwerken van hierarchie posities...';
 $lang['install_admin_set_core_event'] = 'Opzetten van core events...';
 $lang['install_admin_install_modules'] = 'Bezig met installeren van modules...';
-$lang['install_admin_index_search'] = 'Indexeren voor zoek functie... ';
-$lang['install_admin_clear_cache'] = 'Verwijder site cache ';
+$lang['install_admin_index_search'] = 'Indexeren voor zoekfunctie... ';
+$lang['install_admin_clear_cache'] = 'Verwijder site cache (indien aanwezig)';
 $lang['install_admin_emailing'] = 'E-mail mijn admin account informatie...';
-$lang['install_admin_congratulations'] = 'Gefeliciteerd, installatie gelukt - hier is je';
+$lang['install_admin_congratulations'] = 'Gefeliciteerd, installatie gelukt - hier is uw';
 $lang['could_not_connect_db'] = 'Kan geen verbinding maken met de database. Controleer de gebruikersnaam en het wachtwoord, en controleer of de gebruiker rechten heeft op de opgeven database.';
 $lang['cannot_write_config'] = 'Fout: Kan niet schrijven in %s.';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple Admin Account Informatie';
@@ -335,9 +337,9 @@ Dit zijn de nieuwe inlog gegevens:
 gebruikersnaam: %s
 wachtwoord: %s
 
-Log hier in op het beheerpaneel van de site: %s';
-$lang['utma'] = '156861353.799969050.1225024056.1234730819.1234793451.10';
-$lang['utmz'] = '156861353.1232355789.5.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,29866.0.html';
+Log hier in op het beheerpaneel van de website: %s';
+$lang['utma'] = '156861353.799969050.1225024056.1247232408.1247232841.405';
+$lang['utmz'] = '156861353.1246952402.399.67.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,35251.msg166670.html';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
