@@ -1,5 +1,23 @@
 <?php
-$lang['install_admin_locale'] = 'Locale to use for various default date handling functions, etc. Leaving this blank will use the server\'s default or in multilingual environment';
+$lang['invalidemail'] = 'L\'adressa d\'e-mail endatada n\'è betg valaivla';
+$lang['empty_query'] = 'Empty query?? %s';
+$lang['no_db_driver'] = 'Betg chattà drivers da banca da datas cumpatibels';
+$lang['test_check_output_buffering'] = 'Checking output buffering';
+$lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
+$lang['phpinfo'] = 'Mussar infurmaziuns da PHP';
+$lang['mod_security'] = 'Apache Mod Security';
+$lang['test_check_tempnam'] = 'Checking for tempnam Function';
+$lang['test_check_db_drivers'] = 'Drivers da banca da datas';
+$lang['test_check_db_drivers_failed'] = 'Betg chattà dirvers da banca da datas';
+$lang['test_check_register_globals'] = 'Checking PHP register globals';
+$lang['test_check_register_globals_failed'] = 'PHP register globals is active. For security reasons, this should be disabled.';
+$lang['test_check_disable_functions'] = 'Checking PHP disable functions';
+$lang['test_check_disable_functions_failed'] = 'Warning: this is a list of functions disabled on your server.';
+$lang['install_admin_db_port'] = 'Database port';
+$lang['install_admin_db_port_info'] = 'If you don\'t know, leave this blank to use default settings.';
+$lang['install_admin_db_socket'] = 'Database socket';
+$lang['install_admin_db_socket_info'] = 'BETG SUSTEGNÌ.';
+$lang['install_admin_frontendlang'] = 'Default language for the frontend. This adjusts the locale used for various default date handling functions, etc.';
 $lang['install_default_encoding'] = 'In almost all cases, default_encoding should be utf-8. If you\'d like this to be different, change this but keep in mind, however, that the languages translations are all in utf-8';
 $lang['installer_done'] = '[fatg]';
 $lang['installer_failed'] = '[fallà]';
@@ -7,25 +25,28 @@ $lang['create_permission'] = 'Create permission ...';
 $lang['add_column_sql'] = 'Adding column to %s table ...';
 $lang['update_table_sql'] = 'Update %s table ...';
 $lang['installing_module'] = 'Installing %s module ...';
-$lang['updating_schema_version'] = 'Updating schema version %s ...';
-$lang['upgrade_config'] = 'Upgrading config.php';
-$lang['upgrade_config_info'] = 'config upgrade';
+$lang['updating_schema_version'] = 'Actualisar versiun %s dal schema ...';
+$lang['upgrade_config'] = 'Actualisar config.php';
+$lang['upgrade_config_info'] = 'Actualisar config';
 $lang['upgrade_failed_again'] = 'One or more upgrades have failed. Please correct the problem and click the button below to recheck.';
 $lang['upgrade_cache_dirs'] = 'Cleaning cache dirs';
 $lang['cannot_clean_cache_dirs'] = 'Cannot cleaning cache dirs!';
-$lang['upgrade_schema'] = 'Upgrade schema';
+$lang['upgrade_schema'] = 'Actualisar schema';
 $lang['need_upgrade_schema'] = 'CMS is in need of an upgrade.<br />You are now running schema version %s and you need to be upgraded to version %s';
 $lang['schema_ok'] = 'Now the CMS database is up to date using schema version %s';
 $lang['noneed_upgrade_schema'] = 'The CMS database is up to date using schema version %s';
 $lang['upgrade_modules'] = 'Actualisar moduls';
+$lang['noneed_upgrade_modules'] = 'The core modules are up to date';
 $lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of "%s" module from %s to %s ...';
 $lang['upgrade_event_module_from_to'] = 'Upgrading Events of "%s" module from %s to %s ...';
 $lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a "Site Down for Maintainence" message on your site';
 $lang['upgrade_ok'] = 'Please review config.php, modify any new settings as necessary and then reset it\'s permissions back to a locked state. You should also check that all of your modules are up to date, by going to the Extensions -> Modules page and looking for any listed as "Needs Upgrade"';
-$lang['upgrade_complete'] = 'Upgrade process complete';
+$lang['upgrade_complete'] = 'Process d\'acutalisaziun cumplet';
 $lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
 $lang['here'] = 'qua';
 $lang['go_to_admin'] = 'ir en il sectur d\'administraziun';
+$lang['errorfilenot'] = 'Betg chattà datoteca';
+$lang['errorfilenotwritable'] = 'Na pos betg scriver en datoteca';
 $lang['nofiles'] = 'Questa funtauna n\'exista betg!';
 $lang['is_directory'] = 'Questa funtauna è in ordinatur!';
 $lang['is_readable_false'] = 'Questa funtauna n\'è betg legibla!';
@@ -33,8 +54,18 @@ $lang['checksum_match'] = 'Summa da controlla corrispunda!';
 $lang['checksum_not_match'] = 'Summa da controlla na corrispunda betg!';
 $lang['not_checksum'] = 'No checksum retrieve!';
 $lang['format_datetime'] = '%c ';
-$lang['no_checksum_file'] = 'Nagina datoteca da summa da controlla. Chargia ina datoteca da summa da controlla en il root dal CMS!';
-$lang['checksum_file_no_readable'] = 'La datoteca da summa da controlla n\'è betg legibla!';
+$lang['upload_err_ini_size'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini!';
+$lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
+$lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
+$lang['upload_err_no_file'] = 'Chargià si nagina datoteca';
+$lang['upload_err_no_tmp_dir'] = 'Betg chattà in ordinatur temporar.';
+$lang['upload_err_cant_write'] = 'Betg pussibel da scriver datoteca.';
+$lang['upload_err_extension'] = 'File upload stopped by extension.';
+$lang['upload_err_empty'] = 'Datoteca ha grondezza nulla.';
+$lang['upload_err_unknown'] = 'Unknown file upload problem.';
+$lang['function_file_uploads_off'] = 'file_uploads is off in your php configuration!';
+$lang['upload_file_no_readable'] = 'Uploaded file is not readable!';
+$lang['upload_file_multiple'] = 'Multiple file uploads are not allowed!';
 $lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
 $lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. You can to have problems in save templates.';
 $lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
@@ -45,6 +76,7 @@ $lang['checksum'] = 'Checksum test';
 $lang['checksum_file'] = 'Checksum file';
 $lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
 $lang['checksum_passed'] = 'All checksums match!';
+$lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
 $lang['test_check_open_basedir'] = 'Verifitgar per PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.';
 $lang['unlimited'] = 'illimità';
@@ -169,6 +201,7 @@ $lang['install_symbol'] = 'Simbol';
 $lang['install_definition'] = 'Definiziun';
 $lang['install_value_passed'] = 'A required test passed';
 $lang['install_value_failed'] = 'A required test failed';
+$lang['install_error_fragment'] = 'Info Installation Troubleshooting';
 $lang['install_value_required'] = 'A setting is below a required minimum value';
 $lang['install_value_recommended'] = 'A setting is above the required value, but below the recommended value<br />or... A capability that <em>may</em> be required for some optional functionality is unavailable';
 $lang['install_value_exceed'] = 'A setting meets or exceeds the recommended threshhold<br />or... A capability that <em>may</em> be required for some optional functionality is available';
@@ -215,8 +248,13 @@ $lang['test_check_xml_failed'] = 'XML support is not compiled into your php inst
 $lang['test_allow_url_fopen_failed'] = 'When allow url fopen is disabled you will not be able to accessing URL object like file using the ftp or http protocol.';
 $lang['test_remote_url'] = 'Test for remote URL';
 $lang['test_remote_url_failed'] = 'You will probably not be able to open a file on a remote web server.';
-$lang['use_fsockopen'] = '"allow_url_fopen" is disabled, though outgoing connections seem to be permitted.  You may want to contact you host to see about enabling this option.';
-$lang['use_fsockopen_error'] = 'Outgoing http connections do not appear to work.  This will result in module manager, and potentially other functionality failing.';
+$lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
+$lang['remote_connection_timeout'] = 'Connection Timed Out!';
+$lang['search_string_find'] = 'Connection ok!';
+$lang['connection_failed'] = 'Connection failed!';
+$lang['remote_response_ok'] = 'Remote response: ok!';
+$lang['remote_response_404'] = 'Remote response: not found!';
+$lang['remote_response_error'] = 'Remote response: error!';
 $lang['test_check_file_upload'] = 'Checking file uploads';
 $lang['test_check_file_failed'] = 'When file uploads are disabled you will not be able to use any of the file uploading facilities included in CMS Made Simple. If possible, this restriction should be lifted by your system admin to properly use all file management features of the system. Proceed with caution.';
 $lang['test_check_memory'] = 'Checking PHP memory limit';
@@ -286,7 +324,6 @@ $lang['install_admin_emailing'] = 'Trametter las infurmaziuns dal conto a l\'adm
 $lang['install_admin_congratulations'] = 'Congratulations, you are all setup - here is your ';
 $lang['could_not_connect_db'] = 'Betg pussibel da connectar cun la banca da datas. Controllescha ch\'il num d\'utilisader ed il pled-clav sajan corrects ed che quest utilisader haja access a la banca da datas. ';
 $lang['cannot_write_config'] = 'Errur: betg pussibel da scriver sin %s.';
-$lang['install_additional_modules'] = 'Installar ulteriurs moduls. ';
 $lang['email_accountinfo_subject'] = 'Infurmaziuns per l\'administratur da CMS Made Simple';
 $lang['email_accountinfo_message'] = 'Engraziel che ti has installà CMS Made Simple per rumantsch. 
 
@@ -295,8 +332,8 @@ num d\'utilisader: %s
 pled-clav: %s
 
 S\'annunzia qua per l\'administraziun da la pagina: %s';
-$lang['utmz'] = '156861353.1219008274.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['utma'] = '156861353.578823098.1219008274.1219049006.1219687359.3';
+$lang['utma'] = '156861353.3070486175908553000.1244269983.1245694155.1245699630.24';
+$lang['utmz'] = '156861353.1245699630.24.24.utmcsr=blog.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/2009/06/22/announcing-cms-made-simple-16/';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['utmb'] = '156861353.1.10.1245699630';
 ?>
\ No newline at end of file
