@@ -1,4 +1,82 @@
 <?php
+$lang['invalidemail'] = 'Данный электронный адрес недействителен';
+$lang['empty_query'] = 'Пустой запрос?? %s';
+$lang['no_db_driver'] = 'Нет найдено ни одного драйвера базы данных';
+$lang['test_check_output_buffering'] = 'Проверка output buffering';
+$lang['test_check_output_buffering_failed'] = 'Output buffering выключен. Вероятно, вы не сможете использовать некоторые функции.';
+$lang['phpinfo'] = 'Отображение информации PHP';
+$lang['mod_security'] = 'Модуль Apache Mod Security';
+$lang['test_check_tempnam'] = 'Проверка наличия функции tempnam';
+$lang['test_check_db_drivers'] = 'Драйвера баз данных';
+$lang['test_check_db_drivers_failed'] = 'Не найдены драйвера баз данных';
+$lang['test_check_register_globals'] = 'Проверка PHP register globals';
+$lang['test_check_register_globals_failed'] = 'PHP register globals включен. По соображениям безопасности, это должно быть отключено.';
+$lang['test_check_disable_functions'] = 'Проверка отключенных PHP функций';
+$lang['test_check_disable_functions_failed'] = 'Предупреждение: это список функций, которые отключены на вашем сервере.';
+$lang['install_admin_db_port'] = 'Порт базы данных';
+$lang['install_admin_db_port_info'] = 'Если неизвестно, то оставьте это поле пустым.';
+$lang['install_admin_db_socket'] = 'Socket базы данных';
+$lang['install_admin_db_socket_info'] = 'Не поддерживается.';
+$lang['install_admin_frontendlang'] = 'Язык сайта по умолчанию. Это настраивает локаль, которая используется по для различных функций, напрмер, вывод дат и т.д.';
+$lang['install_default_encoding'] = 'Почти во всех случаях, default_encoding должна быть UTF-8.';
+$lang['installer_done'] = '[завершено]';
+$lang['installer_failed'] = '[ошибка]';
+$lang['create_permission'] = 'Создание прав ...';
+$lang['add_column_sql'] = 'Добавление столбцов в таблицу %s ...';
+$lang['update_table_sql'] = 'Обновление таблицы %s ...';
+$lang['installing_module'] = 'Установка модуля %s ...';
+$lang['updating_schema_version'] = 'Обновление схемы базы данных %s ...';
+$lang['upgrade_config'] = 'Обновление config.php';
+$lang['upgrade_config_info'] = 'конфигурация обновления';
+$lang['upgrade_failed_again'] = 'Не удалось выполнить одно или несколько обновлений. Пожалуйста, исправьте проблему, и нажмите на кнопку ниже для новой проверки.';
+$lang['upgrade_cache_dirs'] = 'Очистка кэша';
+$lang['cannot_clean_cache_dirs'] = 'Невозможно очистить кэш!';
+$lang['upgrade_schema'] = 'Обновление схемы';
+$lang['need_upgrade_schema'] = 'CMS нуждается в обновлении.<br />В настоящее время вы работаете со схемой версии %s и вам нужно обновить её до версии %s';
+$lang['schema_ok'] = 'База данных не требует обновления.  Используется схема версии %s';
+$lang['noneed_upgrade_schema'] = 'База данных не требует обновления.  Используется схема версии %s';
+$lang['upgrade_modules'] = 'Обновление модулей';
+$lang['noneed_upgrade_modules'] = 'Стандартные модули не требуют обновления';
+$lang['upgrade_sql_module_from_to'] = 'Обновление SQL для модуля "%s" с %s по %s ...';
+$lang['upgrade_event_module_from_to'] = 'Обновление события для модуля "%s" с %s по %s ...';
+$lang['sitedown_not_removed'] = 'Не удалось удалить файл tmp/cache/SITEDOWN. Удалите его вручную, чтобы удалить сообщение "Сайт закрыт на техническое обслуживание" на вашем сайте';
+$lang['upgrade_ok'] = 'Пожалуйста, проверьте config.php, измените настройки по мере необходимости, и после изменения удалите доступ на запись к файлу. Кроме того, Вы должны убедиться в том, что все ваши модули актуальны, перейдите к Расширения -> Модули и проверьте список на наличие модулей нуждающихся в обновлении';
+$lang['upgrade_complete'] = 'Обновление завершено';
+$lang['upgrade_end'] = 'CMS не требует обновления. Нажмите на %s чтобы перейти на сайт или на %s.';
+$lang['here'] = 'здесь';
+$lang['go_to_admin'] = 'Перейти в административный интерфейс';
+$lang['errorfilenot'] = 'Файл не найден!';
+$lang['errorfilenotwritable'] = 'Файл не доступен для записи!';
+$lang['nofiles'] = 'Данный ресурс не существует!';
+$lang['is_directory'] = 'Данный ресурс представляет собой каталог!';
+$lang['is_readable_false'] = 'Данный ресурс невозможно открыть для чтения!';
+$lang['checksum_match'] = 'Контрольная сумма совпадает!';
+$lang['checksum_not_match'] = 'Контрольная сумма не совпадает!';
+$lang['not_checksum'] = 'Не удалось получить контрольную сумму!';
+$lang['format_datetime'] = '%c ';
+$lang['upload_err_ini_size'] = 'Размер загружаемого файла превышает значение upload_max_filesize в php.ini!';
+$lang['upload_err_form_size'] = 'Размер загружаемого файла превышает значение MAX_FILE_SIZE, указанное в HTML форме.';
+$lang['upload_err_partial'] = 'Файл был загружен лишь частично.';
+$lang['upload_err_no_file'] = 'Файл не был загружен.';
+$lang['upload_err_no_tmp_dir'] = 'Отсутствует временная папка.';
+$lang['upload_err_cant_write'] = 'Не удалось записать файл на диск.';
+$lang['upload_err_extension'] = 'Загрузка файла остановлена.';
+$lang['upload_err_empty'] = 'Файл имеет размер 0.';
+$lang['upload_err_unknown'] = 'Неизвестная ошибка во время загрузки файла.';
+$lang['function_file_uploads_off'] = 'file_uploads отключен в вашей конфигурации PHP!';
+$lang['upload_file_no_readable'] = 'Загруженный файл не читаем!';
+$lang['upload_file_multiple'] = 'Параллельная загрузка нескольких файлов не допускается!';
+$lang['test_check_magic_quotes_gpc'] = 'Magic quotes для операций Get/Post/Cookie';
+$lang['test_check_magic_quotes_gpc_failed'] = 'При включении magic_quotes все одинарные и двойные кавычки, а также слеш будут маскироваться автоматически. Это может привести к серьезным проблемам.';
+$lang['test_check_magic_quotes_runtime'] = 'Magic quotes в выполнении';
+$lang['test_check_magic_quotes_runtime_failed'] = 'При включении magic_quotes большинство функций, возвращающих данные из какого-либо внешнего источника, включая базы данных и текстовые файлы, будут иметь маскировку кавычек. Это может привести к серьезным проблемам.';
+$lang['install_admin_checksum'] = 'Проверить закачанные файлы';
+$lang['upgrade_admin_checksum'] = 'Проверьте вашу систему на обновления';
+$lang['checksum'] = 'Проверка контрольной суммы';
+$lang['checksum_file'] = 'Файл с контрольной суммой';
+$lang['install_test_checksum'] = 'Вы можете проверить целостность файлов вашей системы путем сравнения с первоначальной контрольной суммой. Она может помочь в поиске проблем с закачкой на сервер.';
+$lang['checksum_passed'] = 'Все контрольные суммы совпадают!';
+$lang['checksum_failed'] = 'Контрольные суммы указывают на ошибки. Обратитесь в помощь за дополнительной информацией';
 $lang['test_check_open_basedir'] = 'Опция open_basedir';
 $lang['test_check_open_basedir_failed'] = 'Опция open_basedir включена в конфигурационном файле httpd.conf. У Вас могут возникнуть трудности с некоторыми функциями.';
 $lang['unlimited'] = 'Неограничено';
@@ -37,8 +115,8 @@ $lang['php_information'] = 'Информация о PHP';
 $lang['cms_install_information'] = 'Установочная информация';
 $lang['cms_version'] = 'Версия CMS';
 $lang['systeminfo_copy_paste'] = 'Скопируйте и вставьте выделенный текст в вашe сообщение в форуме.';
-$lang['help_systeminformation'] = 'Информация отображаемая ниже собрана из конфигурационных данных Вашего сервера и представлена здесь в сжатом виде, для того, чтобы вы сразу могли увидеить все настройки, при при попытке диагностировать проблему или обращении за помощью с вашей установкой.';
-$lang['systeminfo'] = 'Мнформация о системе';
+$lang['help_systeminformation'] = 'Информация отображаемая ниже собрана из конфигурационных данных Вашего сервера и представлена здесь в сжатом виде, для того, чтобы вы сразу могли увидеть все настройки при попытке диагностировать проблему или обращении за помощью с вашей установкой.';
+$lang['systeminfo'] = 'Информация о системе';
 $lang['systeminfodescription'] = 'Показ различной информации о Вашей системе, которая может быть полезна при диагностике проблемы.';
 $lang['error'] = 'Ошибка';
 $lang['new_version_available'] = '<em>Примечание:</em> Вышла новая версия CMS Made Simple. Просьба сообщить об этом администратору.';
@@ -52,14 +130,14 @@ $lang['other'] = 'Другие (other)';
 $lang['global_umask'] = 'Права доступа по умолчанию (umask)';
 $lang['errorcantcreatefile'] = 'Невозможно создать файл (проблемы с доступом?)';
 $lang['add'] = 'Добавить';
-$lang['about'] = 'About';
+$lang['about'] = 'Инфо';
 $lang['action'] = 'Действие';
 $lang['actionstatus'] = 'Действие/Статус';
 $lang['active'] = 'Активен';
 $lang['cantremove'] = 'Невозможно удалить';
 $lang['changepermissions'] = 'Изменить права';
 $lang['changepermissionsconfirm'] = 'БУДЬТЕ ОСТОРОЖНЫ\\n\\nЭтой командой всем файлам модуля будет дано право на запись сервером.\\nВы действительно хотите продолжить?';
-$lang['success'] = 'Успех';
+$lang['success'] = 'Удачное завершение';
 $lang['advanced'] = 'Расширенный';
 $lang['back'] = 'Вернуться к меню';
 $lang['cancel'] = 'Отменить';
@@ -74,16 +152,16 @@ $lang['default'] = 'По умолчанию';
 $lang['delete'] = 'Удалить';
 $lang['deleteconfirm'] = 'Вы уверены, что хотите удалить - %s - ?';
 $lang['description'] = 'Описание';
-$lang['directoryexists'] = 'Такой каталог уже существует.';
+$lang['directoryexists'] = 'Такой каталог уже существует';
 $lang['down'] = 'Вниз';
 $lang['edit'] = 'Редактировать';
-$lang['email'] = 'Электронный адрес';
+$lang['email'] = 'Адрес электронной почты';
 $lang['errordeletingfile'] = 'Невозможно удалить файл. Проблемы с правами доступа?';
 $lang['errordirectorynotwritable'] = 'Нет разрешения на запись в каталоге. Это может зависеть от прав на доступ к файлу и его владельца. Безопасный режим также может привести к этой ошибке.';
 $lang['cachenotwritable'] = 'Нет разрешения на запись в каталоге cache. Очистка кэша не будет работать. Пожалуйста, назначьте для каталога tmp/cache права доступа "чтение/запись/выполнение" (777). Возможно Вам также понадобится отключить безопасный режим.';
 $lang['modulesnotwritable'] = 'Нет разрешения на запись в каталоге modules. Если вы хотите устанавливать модули при помощи загрузки файлами XML, то для каталога modules должны быть назначены права доступа "чтение/запись/выполнение" (777). Возможно Вам также понадобится отключить безопасный режим.';
-$lang['false'] = 'False';
-$lang['settrue'] = 'Set True';
+$lang['false'] = 'False ';
+$lang['settrue'] = 'Установить True';
 $lang['filename'] = 'Название файла';
 $lang['filesize'] = 'Размер файла';
 $lang['help'] = 'Помощь';
@@ -94,11 +172,11 @@ $lang['password'] = 'Пароль';
 $lang['passwordagain'] = 'Пароль (повтор)';
 $lang['remove'] = 'Удалить';
 $lang['saveconfig'] = 'Сохранить конфигурацию';
-$lang['true'] = 'True';
-$lang['setfalse'] = 'Set False';
+$lang['true'] = 'True ';
+$lang['setfalse'] = 'Установить False';
 $lang['type'] = 'Тип';
 $lang['typenotvalid'] = 'Тип не действителен';
-$lang['unknown'] = 'Unknown';
+$lang['unknown'] = 'Неизвестно';
 $lang['user'] = 'Пользователь';
 $lang['userdefinedtags'] = 'Пользовательские теги';
 $lang['usermanagement'] = 'Управление пользователями';
@@ -108,6 +186,9 @@ $lang['version'] = 'Версия';
 $lang['install_title'] = 'Установка CMS Made Simple (шаг %s)';
 $lang['install_system'] = 'Установка системы';
 $lang['install_thanks'] = 'Благодарим за установку CMS Made Simple';
+$lang['upgrade_title'] = 'Обновление CMS Made Simple (step %s)';
+$lang['upgrade_system'] = 'Обновление системы';
+$lang['upgrade_thanks'] = 'Спасибо за обновление CMS Made Simple до версии ';
 $lang['install_please_read'] = 'Пожалуйста, прочитайте главу <a href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/ru">Решение проблем</a> в документации CMS Made Simple Wiki.';
 $lang['install_checking'] = 'Проверка прав и настроек PHP';
 $lang['install_test'] = 'Тест';
@@ -120,10 +201,11 @@ $lang['install_symbol'] = 'Символ';
 $lang['install_definition'] = 'Определение';
 $lang['install_value_passed'] = 'Тест успешно пройден';
 $lang['install_value_failed'] = 'Тест не пройден';
+$lang['install_error_fragment'] = 'Помощь по решению проблем';
 $lang['install_value_required'] = 'Значение ниже требуемого минимального значения';
 $lang['install_value_recommended'] = 'Значение выше требуемого минимального значения, но ниже рекомендуемого значения<br /> или ... <em>Возможны</em> сбои в выполнении некоторых функций.';
 $lang['install_value_exceed'] = 'Значение соответствует или превышает рекомендуемое значение, но ниже рекомендуемого значения';
-$lang['install_test_failed'] = 'Один или несколько тестов не пройдены. Вы все же можете установить систему, но некоторые функции могут работать неправильно.<br />Попробуйте исправить проблему и нажмите кнопку "Повторить", или нажмите кнопку "Далее".';
+$lang['install_test_failed'] = 'Один или несколько тестов не пройдены. Вы все же можете установить систему, но некоторые функции могут работать неправильно.<br />Попробуйте исправить проблему и нажмите кнопку "Повторить", или нажмите кнопку "Продолжить".';
 $lang['install_test_passed'] = 'Все тесты успешно пройдены (по крайней мере на минимальном уровне). Пожалуйста, нажмите кнопку "Далее".';
 $lang['install_failed_again'] = 'Один или несколько тестов не были пройдены. Пожалуйста, исправьте проблему и нажмите на кнопку ниже для перепроверки.';
 $lang['install_try_again'] = 'Повторить';
@@ -166,8 +248,13 @@ $lang['test_check_xml_failed'] = 'Поддержка XML отсутствует
 $lang['test_allow_url_fopen_failed'] = 'При отключенной переменной allow_url_fopen Вы не будете иметь доступа к URL файла, используя ftp или http протокол.';
 $lang['test_remote_url'] = 'Проверка удаленной ссылки';
 $lang['test_remote_url_failed'] = 'Вы, вероятно, не сможете открыть файл на удаленном веб-сервере.';
-$lang['use_fsockopen'] = 'Переменная "allow_url_fopen" отключена, хотя исходящие соединения допускаются.  Вы можете связаться с Вашим провайдеров для включения этого параметра.';
-$lang['use_fsockopen_error'] = 'Исходящие соедения http не работают. Это приведет к сбоям в работе менеджера модулей, и, возможно, других функций.';
+$lang['connection_error'] = 'Невозможны исходящие HTTP-соединения! Возможно идет блокировка внешних подключений в firewall или ACL. Это нарушит работу менеджера модулей, и, возможно, других функций.';
+$lang['remote_connection_timeout'] = 'Тайм-аут подключения!';
+$lang['search_string_find'] = 'Подключение OK!';
+$lang['connection_failed'] = 'Ошибка соединения!';
+$lang['remote_response_ok'] = 'Удаленный ответ: ОК!';
+$lang['remote_response_404'] = 'Удаленный ответ: не найдено!';
+$lang['remote_response_error'] = 'Удаленный ответ: ошибка!';
 $lang['test_check_file_upload'] = 'Проверка загрузки файлов';
 $lang['test_check_file_failed'] = 'Если отключена переменная file_uploads, то Вы не сможете воспользоваться функциями загрузки файлов в CMS Made Simple. По возможности это ограничение должно быть снято администратором сервера для правильного использования всех функции управления файлами в системе. Будьте осторожны.';
 $lang['test_check_memory'] = 'Проверка переменной memory_limit';
@@ -190,7 +277,7 @@ $lang['test_check_session_save_path_failed'] = 'Путь session.save_path = "%s
 $lang['test_check_ini_set'] = 'Проверка на использование ini_set';
 $lang['test_check_ini_set_failed'] = 'Хотя использование этой функции php не является обязательным, некоторые модули используют ее (опционально) для увеличения тайм-аута  и разрешения для загрузки больших файлов и т.д. У Вас могут возникнуть трудности с использованием некоторых модулей без этой возможности. Данная проверка может завершиться неудачно при включенном безопасном режиме (см. ниже).';
 $lang['install_admin_header'] = 'Информация об учетной записи администратора';
-$lang['install_admin_info'] = 'Выберите логин, пароль и адрес электронной почты для вашей учетной записи администратора. Убедитесь, что вы запомнили этот пароль, так как при его утере у Вас не будет никакого другого способа войти в административный интерфейс CMS Made Simple.';
+$lang['install_admin_info'] = 'Выберите логин, пароль и адрес электронной почты для вашей учетной записи администратора. Убедитесь, что вы запомнили этот пароль.';
 $lang['install_admin_email'] = 'Адрес электронной почты';
 $lang['install_admin_email_info'] = 'Учетная информация адреса электронной почты';
 $lang['install_admin_email_note'] = '<strong>Примечание:</strong>Эта функция использует php функцию mail. Если Вы не получите это письмо, это может быть свидетельством того, что ваш сервер не правильно настроен, и что вам необходимо связаться с администратором Вашего сервера.';
@@ -217,7 +304,7 @@ $lang['install_admin_importing'] = 'Импорт примеров...';
 $lang['invalid_query'] = 'Неверный запрос: %s';
 $lang['install_creating_table'] = '<p>Создание %s таблицы... [%s]</p>';
 $lang['install_creating_index'] = '<p>Созднание индекса для %s таблицы... [%s]</p>';
-$lang['done'] = 'завершено';
+$lang['done'] = 'готово';
 $lang['failed'] = 'ошибка';
 $lang['install_admin_error_schema'] = 'Ошибка при чтении SQL схемы';
 $lang['install_admin_set_account'] = 'Настройка учетной записи администратора ...';
@@ -237,7 +324,6 @@ $lang['install_admin_emailing'] = 'Отправка информации об у
 $lang['install_admin_congratulations'] = 'Поздравляем, все настроено - здесь ';
 $lang['could_not_connect_db'] = 'Не удалось установить соединение к базе данных. Убедитесь, что правильно заданы имя пользователя и пароль, и этот пользователь имеет доступ к данной базе данных.';
 $lang['cannot_write_config'] = 'Ошибка: Невозможна запись в %s.';
-$lang['install_additional_modules'] = 'Установка дополнительных модулей';
 $lang['email_accountinfo_subject'] = 'Учетная запись администратора CMS Made Simple ';
 $lang['email_accountinfo_message'] = 'Спасибо за установку  CMS Made Simple.
 
@@ -246,8 +332,9 @@ $lang['email_accountinfo_message'] = 'Спасибо за установку  CM
 Пароль: %s
 
 Вход в административный интерфейс сайта: %s';
-$lang['utma'] = '156861353.747163393.1217666005.1217666005.1217666005.1';
-$lang['utmb'] = '156861353';
+$lang['utmz'] = '156861353.1249691644.74.46.utmccn=(referral)|utmcsr=localhost|utmcct=/msnew/install/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.1512485689.1236874721.1249691644.1250401334.75';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1217666005.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-738804097-1250401341499';
+$lang['utmb'] = '156861353.1.10.1250401334';
 ?>
\ No newline at end of file
