@@ -85,12 +85,13 @@ if (isset($CMS_INSTALL_DROP_TABLES)) {
 
 }
 
-
-
 if (isset($CMS_INSTALL_CREATE_TABLES)) {
+	
+	if ($db->dbtype == 'mysql' || $db->dbtype == 'mysqli')
+		@$db->Execute("ALTER DATABASE `" . $db->database . "` DEFAULT CHARACTER SET utf8 COLLATE utf8_general_ci");
 
 	$dbdict = NewDataDictionary($db);
-	$taboptarray = array('mysql' => 'TYPE=MyISAM', 'mysqli' => 'TYPE=MyISAM');
+	$taboptarray = array('mysql' => 'ENGINE MyISAM CHARACTER SET utf8 COLLATE utf8_general_ci', 'mysqli' => 'ENGINE MyISAM CHARACTER SET utf8 COLLATE utf8_general_ci');
 
 
 
