@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 #
-#$Id: class.module.inc.php 5437 2009-02-11 16:23:42Z calguy1000 $
+#$Id: class.module.inc.php 5857 2009-08-03 15:10:52Z calguy1000 $
 
 /**
  * Base module class.
@@ -49,25 +49,6 @@ class CMSModule
 	var $modmisc;
 	var $param_map;
 	var $restrict_unknown_params;
-	var $xml_exclude_files = array('^\.svn' , '^CVS$' , '^\#.*\#$' , '~$', '\.bak$' );
-	var $xmldtd = '
-<!DOCTYPE module [
-  <!ELEMENT module (dtdversion,name,version,description*,help*,about*,requires*,file+)>
-  <!ELEMENT dtdversion (#PCDATA)>
-  <!ELEMENT name (#PCDATA)>
-  <!ELEMENT version (#PCDATA)>
-  <!ELEMENT mincmsversion (#PCDATA)>
-  <!ELEMENT description (#PCDATA)>
-  <!ELEMENT help (#PCDATA)>
-  <!ELEMENT about (#PCDATA)>
-  <!ELEMENT requires (requiredname,requiredversion)>
-  <!ELEMENT requiredname (#PCDATA)>
-  <!ELEMENT requiredversion (#PCDATA)>
-  <!ELEMENT file (filename,isdir,data)>
-  <!ELEMENT filename (#PCDATA)>
-  <!ELEMENT isdir (#PCDATA)>
-  <!ELEMENT data (#PCDATA)>
-]>';
 	var $smarty;
 
 	function CMSModule()
@@ -78,6 +59,7 @@ class CMSModule
 		$this->config =& $gCms->GetConfig();
 
 		global $CMS_ADMIN_PAGE;
+		global $CMS_MODULE_PAGE;
 		if (isset($CMS_ADMIN_PAGE))
 		{
 			$this->curlang = '';
@@ -108,14 +90,17 @@ class CMSModule
 		#$smarty = new CMSModuleSmarty($config, $this->GetName());
 		$this->smarty = &$gCms->GetSmarty();
 
-		$this->SetParameterType('assign',CLEAN_STRING);
-		$this->SetParameterType('module',CLEAN_STRING);
-		$this->SetParameterType('lang',CLEAN_STRING);
-		$this->SetParameterType('returnid',CLEAN_INT);
-		$this->SetParameterType('action',CLEAN_STRING);
-		$this->SetParameterType('showtemplate',CLEAN_STRING);
-		$this->SetParameterType('inline',CLEAN_INT);
-		$this->SetParameters();
+		if( !isset($CMS_ADMIN_PAGE) || isset($CMS_MODULE_PAGE) )
+		  {
+		    $this->SetParameterType('assign',CLEAN_STRING);
+		    $this->SetParameterType('module',CLEAN_STRING);
+		    $this->SetParameterType('lang',CLEAN_STRING);
+		    $this->SetParameterType('returnid',CLEAN_INT);
+		    $this->SetParameterType('action',CLEAN_STRING);
+		    $this->SetParameterType('showtemplate',CLEAN_STRING);
+		    $this->SetParameterType('inline',CLEAN_INT);
+		    $this->SetParameters();
+		  }
 		
 		$this->modinstall = false;
 		$this->modtemplates = false;
@@ -337,7 +322,12 @@ class CMSModule
 	 */
 	function GetParameters()
 	{
-		return $this->params;
+	  if( count($this->params) == 1 && $this->params[0]['name'] == 'lang' )
+	    {
+	      // quick hack to load parameters if they are not already loaded.
+	      $this->SetParameters();
+	    }
+	  return $this->params;
 	}
 
 	/**
@@ -773,7 +763,7 @@ class CMSModule
 	 */
 	function VisibleToAdminUser()
 	{
-		return true;
+	  return true;
 	}
 
 	/**
@@ -802,6 +792,14 @@ class CMSModule
 		return false;
 	}
 
+	/**
+	 * Returns true if the module may support lazy loading in the front end
+	 */
+	function SupportsLazyLoading()
+	{
+	  return false;
+	}
+
 	/**
 	 * ------------------------------------------------------------------
 	 * Login Related Functions
@@ -1597,7 +1595,43 @@ class CMSModule
 	}
 
 
-        /**
+  /**
+	 * Returns the xhtml equivalent of a tooltip help link.
+	 *
+	 * @param string The help text to be shown on mouse over
+	 * @param string The text to be shown as the link, default to a simple question mark
+   * @param string Forces another width of the popupbox than the one set in admin css
+   * @param string An alternative classname for the a-link of the tooltip
+	 */
+  
+  function CreateTooltip($helptext, $linktext="?", $forcewidth="", $classname="admin-tooltip admin-tooltip-box", $href="")
+  {
+    $result='<a class="'.$classname.'"';
+    if ($href!='') $result.=' href="'.$href.'"';
+    $result.='>'.$linktext.'<span';
+    if ($forcewidth!="" && is_numeric($forcewidth)) $result.=' style="width:'.$forcewidth.'px"';
+    $result.='>'.htmlentities($helptext)."</span></a>\n";
+    return $result;
+  }
+
+  /**
+	 * Returns the xhtml equivalent of a tooltip-enabled href link	 This is basically a nice little wrapper
+	 * to make sure that id's are placed in names and also that it's xhtml compliant.
+	 *
+	 * @param string The id given to the module on execution
+	 * @param string The action that this form should do when the link is clicked
+	 * @param string The id to eventually return to when the module is finished it's task
+	 * @param string The text that will have to be clicked to follow the link
+   * @param string The helptext to be shown as tooltip-popup
+	 * @param string An array of params that should be inlucded in the URL of the link.	 These should be in a $key=>$value format.
+	 */
+
+  function CreateTooltipLink($id, $action, $returnid, $contents, $tooltiptext, $params=array())
+  {
+    return $this->CreateTooltip($tooltiptext,$contents,"","admin-tooltip",$this->CreateLink($id,$action,$returnid,"admin-tooltip",$params,"",true) );
+  }
+
+   /**
 	 * Returns the xhtml equivalent of an fieldset and legend.  This is basically a nice little wrapper
 	 * to make sure that id's are placed in names and also that it's xhtml compliant.
 	 *
@@ -2115,7 +2149,7 @@ class CMSModule
 		//Push $this onto front of array
 		$args = func_get_args();
 		array_unshift($args,'');
-		$args[0] = $this;
+		$args[0] = &$this;
 
 		return call_user_func_array('cms_module_Lang', $args);
 	}
@@ -2343,22 +2377,7 @@ class CMSModule
 	 */
 	function RemovePermission($permission_name)
 	{
-		global $gCms;
-		$db =& $gCms->GetDB();
-
-		$query = "SELECT permission_id FROM ".cms_db_prefix()."permissions WHERE permission_name = ?";
-		$row = &$db->GetRow($query, array($permission_name));
-
-		if ($row)
-		{
-			$id = $row["permission_id"];
-
-			$query = "DELETE FROM ".cms_db_prefix()."group_perms WHERE permission_id = ?";
-			$db->Execute($query, array($id));
-
-			$query = "DELETE FROM ".cms_db_prefix()."permissions WHERE permission_id = ?";
-			$db->Execute($query, array($id));
-		}
+	  cms_mapi_remove_permission($permission_name);
 	}
 
 	/**
