@@ -50,7 +50,7 @@ class FileManager extends CMSModule {
 	}
 
 	function GetVersion() {
-		return '0.4.5';
+		return '1.0.1';
 	}
 
 	function GetHelp() {
@@ -86,7 +86,7 @@ class FileManager extends CMSModule {
 	}
 
 	function MinimumCMSVersion() {
-		return "1.5.2";
+		return "1.5.4";
 	}
 
 	function VisibleToAdminUser() {
@@ -190,7 +190,7 @@ class FileManager extends CMSModule {
 				return ($a["size"]>$b["size"]);
 			}
 			case "sizedesc" : {
-				if ($a["dir"] && $b["dir"]) return $this->FileManagerCompareFiles($a,$b,"namedesc");
+				if ($a["dir"] && $b["dir"]) return $this->FileManagerCompareFiles($a,$b,"nameasc");
 				return ($b["size"]>$a["size"]);
 			}
 			default : strncasecmp($a["name"],$b["name"],strlen($a["name"]));				
@@ -471,6 +471,7 @@ class FileManager extends CMSModule {
 			$info=array();
 			$info["name"]=$file;
 			$statinfo=stat($this->Slash($realpath,$file));
+      //print_r($statinfo);
 			if (is_dir($this->Slash($realpath,$file))) {
 				$info["dir"]=true;
 				$info["ext"]="";
@@ -478,7 +479,8 @@ class FileManager extends CMSModule {
 			} else {
 				$info["dir"]=false;
 				$info["size"]=$statinfo["size"];
-				$info["date"]=$statinfo["atime"];
+        
+				$info["date"]=$statinfo["mtime"];
 				$info["url"]=$this->Slashes($config["root_url"].$this->Slash($path,$file));
 				$explodedfile=explode('.', $file);
 				$info["ext"]=array_pop($explodedfile);
