@@ -42,12 +42,12 @@ class News extends CMSModule
 
 	function GetVersion()
 	{
-		return '2.9.3';
+		return '2.10.2';
 	}
 
 	function MinimumCMSVersion()
 	{
-		return '1.5.1';
+		return '1.6.1';
 	}
 
 	function GetAdminDescription()
@@ -107,7 +107,6 @@ class News extends CMSModule
 		$this->SetParameterType('pagenumber',CLEAN_INT);
 		$this->SetParameterType('articleid',CLEAN_INT);
 		$this->SetParameterType('origid',CLEAN_INT);
-		$this->SetParameterType('returid',CLEAN_INT);
 		$this->SetParameterType('showtemplate',CLEAN_STRING);
 		$this->SetParameterType('assign',CLEAN_STRING);
 		$this->SetParameterType('inline',CLEAN_STRING);
@@ -174,7 +173,7 @@ class News extends CMSModule
 
     function GetDfltEmailTemplate()
     {
-      $text = "A new news article has been posted to your website.  The details are as follows:";
+      $text = "A new news article has been posted to your website.  The details are as follows:\n";
       $text .= "Title:      {\$title}\n";
       $text .= "IP Address: {\$ipaddress}\n";
       $text .= "Summary:    {\$summary|strip_tags}\n";
@@ -301,7 +300,7 @@ class News extends CMSModule
 	  $zerotime = $db->DbTimeStamp(1);
 	  $q = "SELECT news_title FROM ".cms_db_prefix()."module_news WHERE
 		       news_id = ?";
-	  if( $this->GetPreference('expired_searchbale',1) == 0 )
+	  if( $this->GetPreference('expired_searchable',1) == 0 )
 	    {
 	      // make sure we don't return expired articles.
 	      // if we don't want em to.
@@ -554,7 +553,17 @@ class News extends CMSModule
     $this->smarty->assign('items', $rowarray );
     $this->smarty->assign('nameprompt', $this->Lang('prompt_name'));
     $this->smarty->assign('defaultprompt', $this->Lang('prompt_default'));
+
     $this->smarty->assign('newtemplatelink',
+			  $this->CreateLink( $id, 'edittemplate', $returnid,
+					     $gCms->variables['admintheme']->DisplayImage('icons/system/newobject.gif', $this->Lang('prompt_newtemplate'),'','','systemicon'),
+					     array('prefix' => $prefix,
+						   'active_tab' => $active_tab,
+						   'title'=>$title,
+						   'mode' => 'add',
+						   'defaulttemplatepref' => $defaulttemplatepref),
+					     '', false, false, '').' '.
+
 			  $this->CreateLink( $id, 'edittemplate', $returnid,
 					     $this->Lang('prompt_newtemplate'),
 					     array('prefix' => $prefix,
