@@ -1,11 +1,11 @@
 <?php
+$lang['expired_searchable'] = 'Articoli spirati possono apparire nei risultati della ricerca';
+$lang['helpshowall'] = 'Mostra tutti gli articoli, senza considerare la data di termine visualizzazione';
 $lang['error_invaliddates'] = 'Una o pi&ugrave; date inserite non sono valide';
 $lang['notify_n_draft_items_sub'] = '%d articolo(i) News';
 $lang['notify_n_draft_items'] = 'Voi avete %s articolo(i) News che non sono ancora pubblicati';
-$lang['helprsscategory'] = 'Con l&#039;uso del parametro makerssbutton, potete specificare una singola categoria nel rss feed';
 $lang['unlimited'] = 'Non limitato';
 $lang['none'] = 'Nessuno';
-$lang['rss_destinationpage'] = 'ID o alias della pagina di destinazione dal feed RSS';
 $lang['anonymous'] = 'Anonimo';
 $lang['unknown'] = 'Sconosciuto';
 $lang['fesubmit_redirect'] = 'ID o alias della pagina da redirigere dopo che un articolo news &egrave; stato inviato via azione fesubmit';
@@ -151,8 +151,6 @@ $lang['numbertodisplay'] = 'Numero di visualizzazioni (vuoto mostra tutte gli ar
 $lang['print'] = 'Stampa';
 $lang['postdate'] = 'Data di pubblicazione';
 $lang['postinstall'] = 'Assicurati di impostare il permesso &quot;Modifica News&quot; agli utenti che dovranno amministrare le News.';
-$lang['rssfeedtitle'] = 'RSS Feed';
-$lang['rsstemplate'] = 'Modello per RSS';
 $lang['selectcategory'] = 'Seleziona la categoria';
 $lang['showchildcategories'] = 'Mostra le categorie discendenti';
 $lang['sortascending'] = 'Ordine crescente';
@@ -167,8 +165,6 @@ $lang['title'] = 'Titolo';
 $lang['options'] = 'Opzioni';
 $lang['optionsupdated'] = 'Le opzioni sono state aggiornate con successo.';
 $lang['useexpiration'] = 'Usa la data di scadenza';
-$lang['showautodiscovery'] = 'Mostra i collegamenti di Auto-Rilevazione RSS';
-$lang['autodiscoverylink'] = 'Auto-Rilevazione dell&#039;URL (vuoto &egrave; il valore predefinito)';
 $lang['eventdesc-NewsArticleAdded'] = 'Mandato quando un articolo &egrave; aggiunto.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Mandato quando un articolo &egrave; aggiunto.</p>
 <h4>Parametri</h4>
@@ -231,9 +227,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Mandato quando una categoria &egrav
 <li>&quot;name&quot; - Nome della categoria cancellata</li>
 </ul>
 ';
+$lang['help_articleid'] = 'Questo parametro &egrave; applicabile solo nella visualizzazione di dettaglio. Permette, se specificata, quale articolo visualizzare nel modo dettaglio. Se viene usato il valore speciale -1, il sistema visualizzar&agrave; gli articoli i pi&ugrave; recenti, pubblicati e non spirati.';
 $lang['helpnumber'] = 'Numero massimo di articoli da visualizzare =- Lasciando vuoto mostrer&agrave; tutti gli articoli.';
 $lang['helpstart'] = 'Inizia dal n-imo articolo -- lasciando vuoto inizier&agrave; dal primo.';
-$lang['helpmakerssbutton'] = 'Fa un bottone per linkare ad un RSS feed di un elemento News.';
 $lang['helpcategory'] = 'Visualizza solo le news di quella categoria. <b>Usa * dopo il nome per visualizzare i suoi discendenti.</b> Categorie multiple possono essere usate se separate con virgola. Lasciando vuoto, mostrer&agrave; tutte le categorie.';
 $lang['helpmoretext'] = 'Testo da visualizzare alla fine di una news se supera la lunghezza del sommario. Il predefinito &egrave; &quot;more...&quot;';
 $lang['helpsummarytemplate'] = 'Usa un Modello separato per visualizzare il sommario dell&#039;articolo. Questo Modello deve esistere ed essere visibile nel Modello Sommario della amministrazione anche se non &egrave; quello predefinito. Se il parametro non &egrave; specificato, allora sar&agrave; usato il Modello corrente marcato come predefinito.';
@@ -248,17 +244,15 @@ $lang['helpbrowsecat'] = 'Mostra una lista di categorie.';
 $lang['helpaction'] = 'Sovrascrive l&#039;azione predefinita. Possibili valori sono &#039;default&#039; per la visualizzazione del sommario e &#039;fesubmit&#039; per la visualizzazione del form nel frontend per permettere agli utenti di pubblicare da l&igrave; gli articoli.';
 $lang['help'] = '<h3>Note Importanti</h3>
 <p>Dalla versione 2.9 News ha rimosso il formatpostdate dai modelli e il parametro dateformat. Per formattare le date dovete usare il modificatore cms_date_format (come indicato nel modello predefinito) ed usare nei Vostri modelli entry->postdate invece di entry->formatpostdate.</p>
-<p>In questa versione &egrave; disabilitata la visualizzazione diretta dei feed RSS. Per gli RSS Feed utilizzare installate i due moduli: CGExtensions e CGFeedMaker.</p>
-	<h3>Che cosa fa?</h3>
-	<p>News &egrave; un modulo per visualizzare eventi sulla tua pagina, simile allo stile blog, solo con pi&ugrave; funzionalit&agrave;!. Quando il module &egrave; installato, in amministrazione una pagina News &egrave; aggiunta in fondo al menu che vi permette di selezionare o aggiungere una categoria. Quando una categoria &egrave; creata o selezionata, sar&agrave; visualizzata una lista di news per quella categoria. Da qui, potete aggiungere, modificare o cancellare news per quella categoria.</p>
+<p>Da questa versione &egrave; disabilitata la visualizzazione diretta dei feed RSS. Per gli RSS Feed utilizzare i due moduli (da installare in questo ordine): CGExtensions e CGFeedMaker.</p>
+<h3>Che cosa fa?</h3>
+<p>News &egrave; un modulo per visualizzare eventi sulla tua pagina, simile allo stile blog, solo con pi&ugrave; funzionalit&agrave;!. Quando il module &egrave; installato, in amministrazione una pagina News &egrave; aggiunta in fondo al menu che vi permette di selezionare o aggiungere una categoria. Quando una categoria &egrave; creata o selezionata, sar&agrave; visualizzata una lista di news per quella categoria. Da qui, potete aggiungere, modificare o cancellare news per quella categoria.</p>
        <h4>Numerous display methods</h4>
 	<p>The parameters supported by the news module, and support for numerous templates of each time mean that your options for displaying news articles are limitless.</p>
         <h4>Custom Fields</h4>
 	<p>The News module allows defining numerous custom fields (including files and images) that will allow you to attach pdf files or numerous images to your articles.</p>
         <h4>Categories</h4>
 	<p>News supplies a hierarchical category mechanism for organizing your articles.  A news article can only be in one place in the hierarchy.</p>
-        <h4>RSS Feeds</h4>
-        <p>News supports generating simple rss feeds from your news articles, so that your visitors can always be up to date with what is happening on your site.</p>
 	<h4>Expiry and Status</h4>
 	<p>Each news article can have an optional expiry date, after which it will not be shown on your web page.  As well, articles can be marked as <em>draft</em> to remove them permanently from your web page.</p>
 	<h3>Sicurezza</h3>
@@ -277,8 +271,8 @@ $lang['help'] = '<h3>Note Importanti</h3>
 <li>Premere Invio</li>
 </ul>
 Seguendo questi passi si dovrebbe risolvere il problema dei nuovi modelli non trovati e altri errori similari di smarty quando aggiorni ad una versione di CMS che contiene News 2.3 o maggiore.</p>';
-$lang['utmz'] = '156861353.1228307453.357.95.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
-$lang['utma'] = '156861353.916584110.1152549583.1228382760.1228388679.359';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.880130626.1236353467.1240505117.1241641977.36';
+$lang['utmz'] = '156861353.1240505117.35.31.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/index.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
