@@ -1,9 +1,9 @@
 <?php
 $lang['expired_searchable'] = 'Verlopen artikelen kunnen verschijnen in de zoekresultaten';
-$lang['helpshowall'] = 'Geef alle artikelen weer, uitgezonderd van einddatum';
+$lang['helpshowall'] = 'Geef alle artikelen weer, ongeacht de einddatum';
 $lang['error_invaliddates'] = 'Een of meerdere ingegeven datums zijn incorrect';
 $lang['notify_n_draft_items_sub'] = '%d Nieuwsbericht(en)';
-$lang['notify_n_draft_items'] = 'U heeft %s nieuwsbericht(en)</a> die niet is/zijn gepubliceerd.';
+$lang['notify_n_draft_items'] = 'U heeft %s nieuwsbericht(en) die niet is/zijn gepubliceerd.';
 $lang['unlimited'] = 'Onbeperkt';
 $lang['none'] = 'Geen';
 $lang['anonymous'] = 'Anoniem';
@@ -30,7 +30,7 @@ $lang['removed'] = 'Verwijderd';
 $lang['msg_contenttype_removed'] = 'Het nieuwsinhoudtype is verwijderd. Plaats de {news} tags met de geschikte parameters in uw sjabloon of in uw pagina om deze functionaliteit te vervangen.';
 $lang['delete_selected'] = 'Verwijder geselecteerde berichten';
 $lang['areyousure_deletemultiple'] = 'Weet u zeker dat al deze nieuwsberichten verwijderd moeten worden?\nDeze actie kan niet ongedaan gemaakt worden!';
-$lang['error_templatenamexists'] = 'Een sjabloon met die naam bestaat al';
+$lang['error_templatenamexists'] = 'Een sjabloon met deze naam bestaat al';
 $lang['error_noarticlesselected'] = 'Er zijn geen berichten geselecteerd';
 $lang['reassign_category'] = 'Verander categorie in';
 $lang['select'] = 'Selecteer';
@@ -41,7 +41,7 @@ $lang['textbox'] = 'Tekstinvoer';
 $lang['checkbox'] = 'Vinkvakje';
 $lang['textarea'] = 'Tekstvak';
 $lang['file'] = 'Bestand';
-$lang['auto_create_thumbnails'] = 'Maak automatisch thumbnails aan van bestanden met deze extensies';
+$lang['auto_create_thumbnails'] = 'Maak automatisch miniaturen aan van bestanden met deze extensies';
 $lang['allowed_upload_types'] = 'Sta alleen uploaden van bestanden met deze extensie toe';
 $lang['fielddefupdated'] = 'Velddefinitie bijgewerkt';
 $lang['editfielddef'] = 'Bewerk velddefinitie';
@@ -52,20 +52,20 @@ $lang['nameexists'] = 'Een veld met die naam bestaat al';
 $lang['notanumber'] = 'Maximum lengte is geen getal';
 $lang['fielddef'] = 'Velddefinitie';
 $lang['fielddefadded'] = 'Velddefinitie toegevoegd';
-$lang['public'] = 'Publiek';
+$lang['public'] = 'Publiek (openbaar)';
 $lang['type'] = 'Type ';
 $lang['info_maxlength'] = 'De maximum lengte betreft alleen tekstinvoervelden';
 $lang['maxlength'] = 'Maximum lengte';
 $lang['addfielddef'] = 'Voeg velddefinitie toe';
 $lang['customfields'] = 'Velddefinities';
 $lang['deprecated'] = 'vervallen';
-$lang['subject_newnews'] = 'Een nieuw artikel is geplaatst';
-$lang['email_subject'] = 'Het onderwerp van de uitgaande email';
-$lang['email_template'] = 'Het formaat van het emailbericht';
-$lang['formsubmit_emailaddress'] = 'Emailadres om de bevestiging van ingezonden nieuws op te ontvangen';
+$lang['subject_newnews'] = 'Er is een nieuw artikel geplaatst';
+$lang['email_subject'] = 'Het onderwerp van de uitgaande E-mail';
+$lang['email_template'] = 'Het formaat van het E-mailbericht';
+$lang['formsubmit_emailaddress'] = 'E-mailadres om de bevestiging van ingezonden nieuws op te ontvangen';
 $lang['extra'] = 'Extra ';
 $lang['uploadscategory'] = 'Uploads-categorie';
-$lang['title_available_templates'] = 'Beschikbare sjablonen';
+$lang['title_available_templates'] = 'Beschikbare Sjablonen';
 $lang['resettodefault'] = 'Herstel naar standaard waarden';
 $lang['title_form_template'] = 'Formuliersjabloon-editor';
 $lang['title_detail_template'] = 'Artikelsjabloon-editor';
@@ -80,7 +80,7 @@ $lang['info_sysdefault'] = '<em>(de inhoud die standaard wordt gebruikt bij het
 $lang['template'] = 'Sjabloon';
 $lang['prompt_name'] = 'Naam';
 $lang['prompt_default'] = 'Standaard';
-$lang['prompt_newtemplate'] = 'Maak een nieuw sjabloon';
+$lang['prompt_newtemplate'] = 'Maak een nieuw sjabloon aan';
 $lang['help_pagelimit'] = 'Maximum aantal te tonen items (per pagina).  Als deze parameter niet is opgegeven, zullen alle resulterende items worden getoond. Als er een maximum is opgegeven, zal er bij meer resultaten dan opgegeven een tekst en link verschijnen om door de resultaten te kunnen scrollen.';
 $lang['prompt_page'] = 'Pagina';
 $lang['firstpage'] = '<< ';
@@ -125,7 +125,7 @@ $lang['detailtemplateupdated'] = 'Het bewerkte artikelsjabloon is opgeslagen in
 $lang['displaytemplate'] = 'Toon sjabloon';
 $lang['edit'] = 'Bewerk';
 $lang['enddate'] = 'Einddatum';
-$lang['endrequiresstart'] = 'Het toevoegen van een einddatum vereist ook een begindatum';
+$lang['endrequiresstart'] = 'Het invoeren van een einddatum vereist ook een begindatum';
 $lang['entries'] = '%s Items';
 $lang['status'] = 'Status ';
 $lang['expiry'] = 'Vervaldatum';
@@ -174,7 +174,7 @@ $lang['eventhelp-NewsArticleAdded'] = '<p>Verzonden als een bericht is toegevoeg
 <li>\&quot;title\&quot; - Titel van het bericht</li>
 <li>\&quot;content\&quot; - Inhoud van het bericht</li>
 <li>\&quot;summary\&quot; - Samenvatting van het bericht</li>
-<li>\&quot;status\&quot; - Status van het bericht (&quot;draft&quot; of &quot;publish&quot;)</li>
+<li>\&quot;status\&quot; - Status van het bericht (&quot;draft&quot; of &quot;publish&quot; d.w.z. concept of publiceren)</li>
 <li>\&quot;start_time\&quot; - Datum vanaf dat het bericht zichtbaar moet zijn</li>
 <li>\&quot;end_time\&quot; - Datum totdat het bericht zichtbaar moet zijn</li>
 <li>\&quot;useexp\&quot; - Of de verloopdatum genegeerd moet worden of niet</li>
@@ -228,15 +228,15 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Verzonden als een categorie is verw
 </ul>
 ';
 $lang['help_articleid'] = 'Deze parameter is alleen van toepassing op het detail overzicht. Het specificeerd welk nieuws artikel wordt getoond in het detail overzicht. Als de speciale waarde &#039;-1&#039; wordt  gebruikt dan zal de module het nieuwste, gepubliceerde en niet verlopen artikel tonen';
-$lang['helpnumber'] = 'Maximum aantal te tonen items -- geen waarde laat alle items zien.';
-$lang['helpstart'] = 'Begin bij het n-de item -- geen waarde start bij het eerste item.';
+$lang['helpnumber'] = 'Maximum aantal te tonen items -- door dit leeg te laten worden alle items getoond. Het is een synoniem voor de pagina limiet parameter.';
+$lang['helpstart'] = 'Begin bij het zoveelste... item -- geen waarde ingevoerd start dan bij het eerste item.';
 $lang['helpcategory'] = 'Toon alleen items van die categorie. <b>Gebruik * achter de naam om onderliggende items te tonen</b>. Meerdere categorie&euml;n scheiden met een komma. Geen waarde laat alle categorie&euml;n zien. Deze parameter kan ook gebruikt worden bij een frontend actie, maar dan kan alleen &eacute;&eacute;n categorie naam worden gebruikt.';
 $lang['helpmoretext'] = 'Tekst die wordt getoond aan het eind van een nieuwsbericht als de samenvatting te lang is. Standaard &quot;meer...&quot;';
 $lang['helpsummarytemplate'] = 'Gebruik een ander sjabloon voor het tonen van het samengevatte bericht. Dit sjabloon moet bestaan en zichtbaar zijn in het samenvattingssjabloon-tabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
 $lang['helpformtemplate'] = 'Gebruik een database-sjabloon om het artikelinzendingsformulier te tonen. Dit sjabloon moet bestaan en zichtbaar zijn in het formuliersjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
 $lang['helpbrowsecattemplate'] = 'Gebruik een database-sjabloon om de categorie-browser te tonen. Dit sjabloon moet bestaan en zichtbaar zijn in het formuliersjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is.';
 $lang['helpdetailtemplate'] = 'Gebruik een ander database-sjabloon voor het tonen van het volledige bericht. Dit sjabloon moet bestaan en zichtbaar zijn in het artikelsjablonentabblad van de News-beheerscherm. Het hoeft niet de standaard keuze te zijn. Als deze parameter niet opgegeven is, dan wordt het sjabloon gebruikt wat als standaard ingesteld is. ';
-$lang['helpsortby'] = 'Veld om op te sorteren. Mogelijkheden zijn: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  Standaard is het &quot;news_date&quot;. Als &quot;random&quot; is opgegeven, wordt de sortasc-parameter genegeerd.';
+$lang['helpsortby'] = 'Veld om op te sorteren. Mogelijkheden zijn: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;, &quot;news_extra&quot;, &quot;end_time&quot;, &quot;start_time&quot;, &quot;random&quot;.  Standaard is het &quot;news_date&quot;. Als &quot;random&quot; is opgegeven, wordt de sortasc-parameter genegeerd.';
 $lang['helpsortasc'] = 'Sorteer nieuwsberichten in oplopende volgorde in plaats van aflopend.';
 $lang['helpdetailpage'] = 'Pagina om het nieuwsbericht in te tonen. Dit kan een paginaalias of -id zijn. Gebruikt om het volledige artikel in een ander sjabloon te tonen dan de samenvatting.';
 $lang['helpshowarchive'] = 'Toon alleen verlopen artikelen.';
@@ -277,8 +277,8 @@ $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 <li>Klik Versturen</li>
 </ul>
 Het uitvoeren van bovenstaande stappen moet het probleem oplossen van verdwenen nieuwssjablonen en vergelijkbare smarty-fouten als u upgrade naar een versie van CMSMS die de News-module versie 2.3 of nieuwer heeft.</p>';
-$lang['utma'] = '156861353.799969050.1225024056.1234730819.1234793451.10';
-$lang['utmz'] = '156861353.1232355789.5.3.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,29866.0.html';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.799969050.1225024056.1244555916.1244572805.339';
+$lang['utmz'] = '156861353.1244550087.337.59.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,34493.new.html';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
