@@ -1,11 +1,11 @@
 <?php
+$lang['expired_searchable'] = 'Новости могут появляться в результатах поиска, независимо от даты окончания';
+$lang['helpshowall'] = 'Показать все новости, независимо от даты окончания';
 $lang['error_invaliddates'] = 'Одна или несколько дат введены неверно';
 $lang['notify_n_draft_items_sub'] = '%d новостных статей';
-$lang['notify_n_draft_items'] = 'Вы имеете  %s неопубликованных статей';
-$lang['helprsscategory'] = 'Для использования с параметром makerssbutton , этот параметр позволяет определить единую категорию для использования в rss-канале ';
+$lang['notify_n_draft_items'] = 'У вас есть не опубликованые новости, всего %s';
 $lang['unlimited'] = 'Неограничено';
-$lang['none'] = 'Ничто';
-$lang['rss_destinationpage'] = 'ID страницы или алиас для отображения новостей в формате RSS';
+$lang['none'] = 'Нет';
 $lang['anonymous'] = 'Анонимный';
 $lang['unknown'] = 'Неизвестно';
 $lang['fesubmit_redirect'] = 'ID страницы или алиас для переброса пользователя после добавления новости через форму на сайте';
@@ -14,12 +14,12 @@ $lang['title_browsecat_template'] = 'Просмотр категории ред
 $lang['title_browsecat_sysdefault'] = 'Обзор по умолчанию категории шаблона';
 $lang['browsecattemplate'] = 'Обзор категории шаблонов';
 $lang['error_filesize'] = 'Загруженный файл превысил максимально разрешённый размер';
-$lang['post_date_desc'] = 'Дата публикации по убыванию';
-$lang['post_date_asc'] = 'Дата публикации по возрастанию';
-$lang['expiry_date_desc'] = 'Дата истечения срока по убыванию';
-$lang['expiry_date_asc'] = 'Дата истечения срока по возрастанию';
-$lang['title_desc'] = 'Заголовок по убыванию';
-$lang['title_asc'] = 'Заголовок по возрастанию';
+$lang['post_date_desc'] = 'Дате (Новые вверху)';
+$lang['post_date_asc'] = 'Дате (Новые ввнизу)';
+$lang['expiry_date_desc'] = 'Дате окончания (Истекшие внизу)';
+$lang['expiry_date_asc'] = 'Дате окончания (Истекшие вверху)';
+$lang['title_desc'] = 'Заголовоку (от Я до А)';
+$lang['title_asc'] = 'Заголовоку (от А до Я)';
 $lang['fesubmit_status'] = 'Статус новостей представленных через интерфейс';
 $lang['error_invalidfiletype'] = 'Не удается загрузить этот тип файла';
 $lang['error_upload'] = 'Произошла проблема при загрузке файла';
@@ -88,9 +88,9 @@ $lang['prevpage'] = '<';
 $lang['nextpage'] = '>';
 $lang['lastpage'] = '>>';
 $lang['prompt_of'] = 'из';
-$lang['prompt_pagelimit'] = 'Лимит страниц';
-$lang['prompt_sorting'] = 'Отсортировано по';
-$lang['title_filter'] = 'Фильтры';
+$lang['prompt_pagelimit'] = 'Новостей на страницу';
+$lang['prompt_sorting'] = 'Сортировать по';
+$lang['title_filter'] = 'Фильтр';
 $lang['published'] = 'Опубликовано';
 $lang['draft'] = 'Черновик';
 $lang['expired'] = 'Истекает';
@@ -151,10 +151,8 @@ $lang['numbertodisplay'] = 'Количество для показа (если 
 $lang['print'] = 'Печать';
 $lang['postdate'] = 'Дата публикации';
 $lang['postinstall'] = 'Убедитесь, что вы установили права "Modify News" для тех пользователей, кто должен администрировать материалы.';
-$lang['rssfeedtitle'] = 'RSS лента CMS Made Simple';
-$lang['rsstemplate'] = 'RSS шаблон';
 $lang['selectcategory'] = 'Выберите категорию';
-$lang['showchildcategories'] = 'Показать дочерние категории';
+$lang['showchildcategories'] = 'Показывать подкатегории';
 $lang['sortascending'] = 'Сортировать по возрастанию';
 $lang['startdate'] = 'Дата начала';
 $lang['startoffset'] = 'Начать вывод новостей с n-ой';
@@ -167,8 +165,6 @@ $lang['title'] = 'Заголовок';
 $lang['options'] = 'Опции';
 $lang['optionsupdated'] = 'Опции были успешно обновлены.';
 $lang['useexpiration'] = 'Использовать дату окончания';
-$lang['showautodiscovery'] = 'Показать ссылку автооткрытия ленты';
-$lang['autodiscoverylink'] = 'URL автооткрытия ленты (пусто для значения по умолчанию)';
 $lang['eventdesc-NewsArticleAdded'] = 'Отправляется, когда статья добавлена.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Отправляется, когда статья добавлена.</p>
 <h4>Параметры</h4>
@@ -231,9 +227,9 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Отправлется, когда
 <li>\\"name\\" - Имя удаленной категории</li>
 </ul>
 ';
+$lang['help_articleid'] = 'Этот параметр применяется только для подробного просмотра. Это позволяет указать, какие статьи новостей на дисплее в режиме "подробно". Если специальное значение -1 используется, то система будет показывать новейшую опубликованную, не истекшую статью.';
 $lang['helpnumber'] = 'Максимальное число отображаемых элементов =- в случае незаполнения будет показывать все объекты.';
 $lang['helpstart'] = 'Начать с n-го объекта -- в случае незаполнения будет начинать с первого объекта.';
-$lang['helpmakerssbutton'] = 'Создать кнопку с ссылкой на RSS новостей. ';
 $lang['helpcategory'] = 'Отображать только объекты данной категории. <b>Необходимо использовать * после имени, чтобы показать дочерние объекты.</b> чтобы ввести несколько категорий, их нужно разделить запятыми. В случае незаполнения, будет показывать все категории.';
 $lang['helpmoretext'] = 'Текст, отображаемый в конце новостного объекта если он превышает длину резюме. По умолчанию "more..."';
 $lang['helpsummarytemplate'] = 'Использовать отдельный шаблон для отображения резюме. Он должен быть расположен в папке modules/News/templates.';
@@ -276,8 +272,9 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.1781493382045874700.1227792799.1228903388.1228909115.17';
-$lang['utmz'] = '156861353.1228474680.12.5.utmccn=(referral)|utmcsr=estetman.ru|utmcct=/admin/systeminfo.php|utmcmd=referral';
+$lang['utmz'] = '156861353.1249691644.74.46.utmccn=(referral)|utmcsr=localhost|utmcct=/msnew/install/index.php|utmcmd=referral';
+$lang['utma'] = '156861353.1512485689.1236874721.1249691644.1250401334.75';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353';
+$lang['qca'] = 'P0-738804097-1250401341499';
+$lang['utmb'] = '156861353.1.10.1250401334';
 ?>
\ No newline at end of file
