@@ -2,16 +2,11 @@
 
 if (!$this->VisibleToAdminUser()) $this->Redirect($id,"defaultadmin",$returnid);
 
-if (isset($params["reset"])) {
+if (isset($params["resetplugins"])) {
   $this->ResetSettings("plugins");
   $this->Redirect($id,"defaultadmin",$returnid,array("module_message"=>$this->Lang("settingsreset"),"tab"=>"plugins"));
 }
 
-if (isset($params["resetall"])) {
-  $this->ResetSettings();
-  $this->Redirect($id,"defaultadmin",$returnid,array("module_message"=>$this->Lang("allsettingsreset"),"tab"=>"plugins"));
-}
-
 $plugins = "";
 $d = dir(dirname(__FILE__).'/tinymce/jscripts/tiny_mce/plugins');
 $exclude = array( '.', '..', '_template', 'readme.txt', 'cleanup', 'autosave','cmsmslink' );
