@@ -20,28 +20,29 @@ if(session_id() == "") {
 
 
 $frontend=false;
-if (isset($_SESSION["tiny_live_frontend"]) && $_SESSION["tiny_live_frontend"]!="") {
+/*if (isset($_SESSION["tiny_live_frontend"]) && $_SESSION["tiny_live_frontend"]!="") {
   $frontend=true;
   //$_SESSION["tiny_live_frontend"]="";//needed in GenerateConfig()!!
+}*/
+if (isset($_GET["frontend"]) && $_GET["frontend"]=="yes") {
+  $frontend=true;
 }
 
 $config=& $gCms->GetConfig();
 
-
-
-
-
 $templateid="";
-if (isset($_SESSION["tiny_live_templateid"])) $templateid=$_SESSION["tiny_live_templateid"]; 
+if (isset($_GET["templateid"])) $templateid=$_GET["templateid"];
 
+$languageid="";
+if (isset($_GET["languageid"])) $languageid=$_GET["languageid"];
 
 //$basepath = $gCms->config["root_url"].'/modules/TinyMCE/tinymce/jscripts/tiny_mce/';
 //$css = $gCms->config['root_url'] . "/modules/TinyMCE/content_css.php?mediatype=screen&templateid=" .$_SESSION["tiny_live_templateid"] ;
 
 $modules =& $gCms->modules;
 $tiny=$modules["TinyMCE"]['object'];
-$configcontent=$tiny->GenerateConfig();
+$configcontent=$tiny->GenerateConfig($frontend,$templateid,$languageid);
 echo $configcontent;
-$_SESSION["tiny_live_frontend"]="";
+//$_SESSION["tiny_live_frontend"]="";
 
 ?>
